---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:1999-07-30;300
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19990830&codiceRedaz=099G0372&dataVigenza=20251104
dataGU: 19990830
codiceRedaz: 099G0372
dataVigenza: 20251104
---

# Riforma dell'organizzazione del Governo, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Vista la legge 15 marzo 1997, n.59, recante delega al Governo per il conferimento di funzioni e compiti alle regioni ed agli enti locali, per la riforma della pubblica amministrazione e per la semplificazione amministrativa, ed in particolare l'articolo 11, comma 1, come modificato dall'articolo 7 della legge 15 maggio 1997, n.127, dall'articolo 1 della legge 16 giugno 1998, n.191, e dall'articolo 9 della legge 8 marzo 1999, n.50;

Visti l'articolo 11, comma 1, lettera a), e l'articolo 12 della legge 15 marzo 1997, n. 59;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 4 giugno 1999;

Sentite le organizzazioni sindacali maggiormente rappresentative;

Acquisito il parere della Commissione parlamentare bicamerale di cui all'articolo 5 della legge 15 marzo 1997, n. 59;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 29 luglio 1999;

Sulla proposta del Presidente del Consiglio dei Ministri, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica;

E M A N A il seguente decreto legislativo:

## Art. 1. - (oggetto)

1. Il presente decreto legislativo, in attuazione della delega disposta con l'articolo 11 della legge 15 marzo 1997, n. 59, modificato dall'articolo 1 della legge 16 giugno 1998, n. 191 e dall'articolo 9 della legge 8 marzo 1999, n.5O, detta norme per la razionalizzazione, il riordino, la soppressione e la fusione di ministeri, l'istituzione di agenzie, il riordino dell'amministrazione periferica dello Stato.

2. In nessun caso le norme del presente decreto legislativo possono essere interpretate nel senso della attribuzione allo Stato, alle sue amministrazioni o ad enti pubblici nazionali, di funzioni e compiti trasferiti, delegati o comunque attribuiti alle regioni, agli enti locali e alle autonomie funzionali dalle disposizioni vigenti alla data di entrata in vigore del presente decreto legislativo, ovvero da conferire ai sensi dei decreti legislativi emanati in attuazione della legge 15 marzo 1997, n.59.

## Art. 2. - (Ministeri)

1. I Ministeri sono i seguenti: 1) Ministero degli affari esteri e della cooperazione internazionale; 2) Ministero dell'interno; 3) Ministero della giustizia; 4) Ministero della difesa; 5) Ministero dell'economia e delle finanze; ((6) Ministero)) delle imprese e del made in Italy; ((7) Ministero)) dell'agricoltura, della sovranita' alimentare e delle foreste; ((8) Ministero)) dell'ambiente e della sicurezza energetica; ((9) Ministero)) delle infrastrutture e dei trasporti; 10) Ministero del lavoro e delle politiche sociali; ((11) Ministero)) dell'istruzione e del merito; 12) Ministero dell'universita' e della ricerca; 13) Ministero della cultura; 14) Ministero della salute; 15) Ministero del turismo.

2. I ministeri svolgono, per mezzo della propria organizzazione, nonche' per mezzo delle agenzie disciplinate dal presente decreto legislativo, le funzioni di spettanza statale nelle materie e secondo le aree funzionali indicate per ciascuna amministrazione dal presente decreto, nel rispetto degli obblighi derivanti dall'appartenenza all'Unione europea.

3. Sono in ogni caso attribuiti ai ministri, anche con riferimento alle agenzie dotate di personalita' giuridica, la titolarita' dei poteri di indirizzo politico di cui agli articoli 3 e 14 del decreto legislativo n.29 del 1993 e la relativa responsabilita'.

4. I ministeri intrattengono, nelle materie di rispettiva competenza, i rapporti con l'Unione europea e con le organizzazioni e le agenzie internazionali di settore fatte salve le competenze del Ministero degli affari esteri e della cooperazione internazionale.

4-bis. Il numero dei Ministeri e' stabilito in quindici. Il numero totale dei componenti del Governo a qualsiasi titolo, ivi compresi Ministri senza portafoglio, vice Ministri e Sottosegretari, non puo' essere superiore a sessantacinque e la composizione del Governo deve essere coerente con il principio sancito nel secondo periodo del primo comma dell'articolo 51 della Costituzione.

## L'ORGANIZZAZIONE DEI MINISTERI

### Art. 3.

(( (Disposizioni generali). )) ((

1. Nei Ministeri costituiscono strutture di primo livello, alternativamente:

- a) i dipartimenti;
- b) le direzioni generali.

2. Nei Ministeri in cui le strutture di primo livello sono costituite da dipartimenti non puo' essere istituita la figura del segretario generale. Nei Ministeri organizzati in dipartimenti l'ufficio del segretario generale, ove previsto da precedenti disposizioni di legge o regolamento, e' soppresso. I compiti attribuiti a tale ufficio sono distribuiti tra i capi dipartimento con il regolamento di cui all'articolo 4.

### Art. 4. - (Disposizioni sull'organizzazione)

1. L'organizzazione, la dotazione organica, l'individuazione degli uffici di livello dirigenziale generale ed il loro numero, le rela- tive funzioni e la distribuzione dei posti di funzione dirigenziale, l'individuazione dei dipartimenti, nei casi e nei limiti fissati dalle disposizioni del presente decreto legislativo, e la definizione dei rispettivi compiti sono stabiliti con regolamenti o con decreti del ministro emanati ai sensi dell'articolo 17, comma 4 bis, della legge 23 agosto 1988, n.400. Si applica l'articolo 19 della legge 15 marzo 1997, n.59. I regolamenti prevedono la soppressione dei ruoli esistenti e restituzione di un ruolo unico del personale non dirigenziale di ciascun ministero, articolato in aree dipartimentali e per direzioni generali. Fino all'istituzione del ruolo unico del personale non dirigenziale di ciascun ministero, i regolamenti assicurano forme ordinarie di mobilita' tra i diversi dipartimenti e le diverse direzioni generali, nel rispetto dei requisiti di professionalita' richiesti per l'esercizio delle relative funzioni, ferme restando le normative contrattuali in materia. La nuova organizzazione e la dotazione organica del personale non devono comunque comportare incrementi di spesa.

2. I ministeri che si avvalgono di propri sistemi informativi automatizzati sono tenuti ad assicurarne l'interconnessione con i sistemi informativi automatizzati delle altre amministrazioni centrali e locali per il tramite della rete unitaria delle pubbliche amministrazioni.

3. Il regolamento di cui al precedente comma 1 si attiene, inoltre, ai criteri fissati dall'articolo 1 della legge 7 agosto 1990, n.241 e dall'articolo 2 del decreto legislativo 3 febbraio 1993, n. 29 e suc- cessive modificazioni e integrazioni.

4. All'individuazione degli uffici di livello dirigenziale non generale di ciascun ministero e alla definizione dei relativi compiti (( , nonche' la distribuzione dei predetti uffici tra le strutture di livello dirigenziale generale, )) si provvede con decreto ministeriale di natura non regolamentare.

((

4-bis. La disposizione di cui al comma 4 si applica anche in deroga alla eventuale distribuzione degli uffici di livello dirigenziale non generale stabilita nel regolamento di organizzazione del singolo Ministero.

))

5. Con le medesime modalita' di cui al precedente comma 1 si procede alla revisione periodica dell'organizzazione ministeriale, con cadenza almeno biennale.

6. I regolamenti di cui al comma 1 raccolgono tutte le disposizioni normative relative a ciascun ministero. Le restanti norme vigenti sono abrogate con effetto dalla data di entrata in vigore dei regolamenti medesimi.

### Art. 5. - (I dipartimenti)

1. I dipartimenti sono costituiti per assicurare l'esercizio organico ed integrato delle funzioni del ministero. Ai dipartimenti sono attribuiti compiti finali concernenti grandi aree di materie omogenee e i relativi compiti strumentali, ivi compresi quelli di indirizzo e coordinamento delle unita' di gestione in cui si articolano i dipartimenti stessi, quelli di organizzazione e quelli di gestione delle risorse strumentali, finanziarie ed umane ad essi attribuite.

2. L'incarico di capo del dipartimento viene conferito in conformita' alle disposizioni di cui all'articolo 19 del decreto legislativo 3 febbraio 1993, n.29 e successive modificazioni ed integrazioni.

3. Il capo del dipartimento svolge compiti di coordinamento, direzione e controllo degli uffici di livello dirigenziale generale compresi nel dipartimento stesso, al fine di assicurare la continuita' delle funzioni dell'amministrazione ed e' responsabile dei risultati complessivamente raggiunti dagli uffici da esso dipendenti, in attuazione degli indirizzi del ministro.

4. Dal capo del dipartimento dipendono funzionalmente gli uffici di livello dirigenziale generale compresi nel dipartimento stesso.

5. Nell'esercizio, dei poteri di cui ai precedenti commi 3 e 4, in particolare, il capo del dipartimento:

- a) determina i programmi per dare attuazione agli indirizzi del ministro;
- b) alloca le risorse umane, finanziarie e strumentali disponibili per l'attuazione dei programmi secondo principi di economicita', efficacia ed efficienza, nonche' di rispondenza del servizio al pubblico interesse;
- c) svolge funzioni di propulsione, di coordinamento di controllo e di vigilanza nei confronti degli uffici del dipartimento;
- d) promuove e mantiene relazioni con gli organi competenti dell'Unione europea per la trattazione di questioni e problemi attinenti al proprio dipartimento;
- e) adotta gli atti per l'utilizzazione ottimale del personale secondo criteri di efficienza, disponendo gli opportuni trasferimenti di personale all'interno del dipartimento;
- f) e' sentito dal ministro ai fini dell'esercizio del potere di proposta per il conferimento degli incarichi di direzione degli uffici di livello dirigenziale generale, ai sensi dell'articolo 19, comma 4, del decreto legislativo 3 febbraio 1993, n.29;
- g) puo' proporre al ministro l'adozione dei provvedimenti di revoca degli incarichi di direzione degli uffici di livello dirigenziale generale, ai sensi dell'articolo 19, comma 7, del decreto legislativo 3 febbraio 1993, n.29 e, comunque, viene sentito nel relativo procedimento;
- h) e' sentito dal ministro per l'esercizio delle attribuzioni a questi conferite dall'articolo 14, comma 1, del decreto legislativo 3 febbraio 1993, n.29.

6. Con le modalita' di cui all'articolo 16, comma 5, del decreto legislativo 3 febbraio 1993, n.29, possono essere definiti ulteriori compiti del capo del dipartimento.

### Art. 6.

(( (Il segretario generale). )) ((

1. Nei Ministeri in cui le strutture di primo livello sono costituite da direzioni generali puo' essere istituito l'ufficio del segretario generale. Il segretario generale, ove previsto,opera alle dirette dipendenze del Ministro. Assicura il coordinamento dell'azione amministrativa, provvede all'istruttoria per l'elaborazione degli indirizzi e dei programmi di competenza del Ministro, coordina gli uffici e le attivita' del Ministero, vigila sulla loro efficienza e rendimento e ne riferisce periodicamente al Ministro.

### Art. 7. - (Uffici di diretta collaborazione con il ministro)

1. La costituzione e la disciplina degli uffici di diretta collaborazione del ministro, per l'esercizio delle funzioni ad esso attribuite dagli articoli 3 e 14 del decreto legislativo 3 febbraio 1993, n. 29 e successive modificazioni ed integrazioni, l'assegnazione di personale a tali uffici e il relativo trattamento economico, il riordino delle segreterie particolari dei sottosegretari di Stato, sono regolati dall'articolo 14, comma 2, del decreto legislativo 3 febbraio 1993, n. 29.

2. I regolamenti di cui al suddetto articolo 14, comma 2, del decreto legislativo 3 febbraio 1993, n.29, si attengono, tra l'altro, ai seguenti principi e criteri direttivi:

- a) attribuzione dei compiti di diretta collaborazione secondo criteri che consentano l'efficace e funzionale svolgimento dei compiti di definizione degli obiettivi, di elaborazione delle politiche pubbliche e di valutazione della relativa attuazione e delle connesse attivita' di comunicazione, nel rispetto del principio di distinzione tra funzioni di indirizzo e compiti di gestione;
- b) assolvimento dei compiti di supporto per l'assegnazione e la ripartizione delle risorse ai dirigenti preposti ai centri di responsabilita', ai sensi dell'articolo 3 del decreto legislativo 7 agosto 1997, n. 279, anche in funzione della verifica della gestione effettuata dagli appositi uffici, nonche' del compito di promozione e sviluppo dei sistemi informativi;
- c) organizzazione degli uffici preposti al controllo interno di diretta collaborazione con il ministro, secondo le disposizioni del decreto legislativo di riordino e potenziamento dei meccanismi e strumenti di monitoraggio e valutazione dei costi, dei rendimenti e dei risultati dell'attivita' svolta dalle amministrazioni pubbliche, in modo da assicurare il corretto ed efficace svolgimento dei compiti ad essi assegnati dalla legge, anche attraverso la provvista di adeguati mezzi finanziari, organizzativi e personali;
- d) organizzazione del settore giuridico-legislativo in modo da assicurare: il raccordo permanente con l'attivita' normativa del Parlamento, l'elaborazione di testi normativi del Governo garantendo la valutazione dei costi della regolazione, la qualita' del linguaggio normativo, l'applicabilita' delle norme introdotte, lo snellimento e la semplificazione della normativa, la cura dei rapporti con gli altri organi costituzionali, con le autorita' indipendenti e con il Consiglio di Stato;
- e) attribuzione dell'incarico di Capo degli uffici di cui al comma 1 ad esperti, anche estranei all'amministrazione, dotati di elevata professionalita'.

## LE AGENZIE

### Art. 8. - (L'ordinamento)

1. Le agenzie sono strutture che, secondo le previsioni del presente decreto legislativo, svolgono attivita' a carattere tecnico-operativo di interesse nazionale, in atto esercitate da ministeri ed enti pubblici. Esse operano al servizio delle amministrazioni pubbliche, comprese anche quelle regionali e locali.

2. Le agenzie hanno piena autonomia nei limiti stabiliti dalla legge e sono sottoposte al controllo della Corte dei conti, ai sensi dell'articolo 3, comma 4, della legge 14 gennaio 1994, n.20. Esse sono sottoposte ai poteri di indirizzo e di vigilanza di un ministro secondo le disposizioni del successivo comma 4, e secondo le disposizioni generali dettate dagli articoli 3, comma 1, e 14 dei decreto legislativo n. 29 del 1993 e successive modificazioni.

3. L'incarico di direttore generale dell'agenzia viene conferito in conformita' alle disposizioni dettate dal precedente articolo 5 del presente decreto per il conferimento dell'incarico di capo del dipartimento.

4. Con regolamenti emanati ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, su proposta del presidente del consiglio dei ministri e dei ministri competenti, di concerto con il ministro del tesoro, del bilancio e della programmazione economica, sono emanati gli statuti delle agenzie istituite dal presente decreto legislativo, in conformita' ai seguenti principi e criteri direttivi:

- a) definizione delle attribuzioni del direttore generale dell'agenzia anche sulla base delle previsioni contenute nel precedente articolo 5 del presente decreto con riferimento al capo del dipartimento;
- b) attribuzione al direttore generale e ai dirigenti dell'agenzia dei poteri e della responsabilita' della gestione, nonche' della responsabilita' per il conseguimento dei risultati fissati dal ministro competente nelle forme previste dal presente decreto, nell'ambito, ove possibile, di massimali di spesa predeterminati dal bilancio o, nell'ambito di questo, dal ministro stesso;
- c) previsione di un comitato direttivo, composto da dirigenti dei principali settori di attivita' dell'agenzia, in numero non superiore a quattro, con il compito di coadiuvare il direttore generale nell'esercizio delle attribuzioni ad esso conferite;
- d) definizione dei poteri ministeriali di vigilanza, che devono comprendere, comunque, oltre a quelli espressamente menzionati nel precedente comma 2: d1) l'approvazione dei programmi di attivita' dell'agenzia e di approvazione dei bilanci e rendiconti, secondo modalita' idonee a garantire l'autonomia dell'agenzia; d2) l'emanazione di direttive con l'indicazione degli obiettivi da raggiungere; d3) l'acquisizione di dati e notizie e l'effettuazione di ispezioni per accertare l'osservanza delle prescrizioni impartite; d4) l'indicazione di eventuali specifiche attivita' da intraprendere;
- e) definizione, tramite una apposita convenzione da stipularsi tra il ministro competente e il direttore generale dell'agenzia, degli obiettivi specificamente attribuiti a questa ultima, nell'ambito della missione ad essa affidata dalla legge; dei risultati attesi in un arco temporale determinato; dell'entita' e delle modalita' dei finanziamenti da accordare all'agenzia stessa; delle strategie per il miglioramento dei servizi; delle modalita' di verifica dei risultati di gestione; delle modalita' necessarie ad assicurare al ministero competente la conoscenza dei fattori gestionali interni all'agenzia, quali l'organizzazione, i processi e l'uso delle risorse;
- f) attribuzione all'agenzia di autonomia di bilancio, nei limiti del fondo stanziato a tale scopo in apposita unita' previsionale di base dello stato di previsione del ministero competente; attribuzione altresi' all'agenzia di autonomi poteri per la determinazione delle norme concernenti la propria organizzazione ed il proprio funzionamento, nei limiti fissati dalla successiva lettera l);
- g) regolazione su base convenzionale dei rapporti di collaborazione, consulenza, assistenza, servizio, supporto, promozione tra l'agenzia ed altre pubbliche amministrazioni, sulla base di convenzioni quadro da deliberarsi da parte del ministro competente;
- h) previsione di un collegio dei revisori, nominato con decreto del ministro competente, composto di tre membri, due dei quali scelti tra gli iscritti all'albo dei revisori dei conti o tra persone in possesso di specifica professionalita'; previsione di un membro supplente; attribuzione dei relativi compensi, da determinare con decreto del ministro competente di concerto con quello del tesoro;
- i) istituzione di un apposito organismo preposto al controllo di gestione ai sensi del decreto legislativo di riordino e potenziamento dei meccanismi e strumenti di monitoraggio e valutazione dei costi, dei rendimenti e dei risultati dell'attivita' svolta dalle amministrazioni pubbliche;
- l) determinazione di una organizzazione dell'agenzia rispondente alle esigenze di speditezza, efficienza ed efficacia dell'azione amministrativa; attribuzione a regolamenti interni di ciascuna agenzia, adottati dal direttore generale dell'agenzia e approvati dal ministro competente, della possibilita' di adeguare l'organizzazione stessa, nei limiti delle disponibilita' finanziarie, alle esigenze funzionali, e devoluzione ad atti di organizzazione di livello inferiore di ogni altro potere di organizzazione; applicazione dei criteri di mobilita' professionale e territoriale previsti dal decreto legislativo 3 febbraio 1993, n.29 e successive modificazioni e integrazioni;
- m) facolta' del direttore generale dell'agenzia di deliberare e proporre all'approvazione dei ministro competente, di concerto con quello del tesoro, regolamenti interni di contabilita' ispirati, ove richiesto dall'attivita' dell'agenzia, a principi civilistici, anche in deroga alle disposizioni sulla contabilita' pubblica.

### Art. 9. - (Il personale e la dotazione finanziaria)

1. Alla copertura dell'organico delle agenzie, nei limiti determinati per ciascuna di esse dai successivi articoli, si provvede, nell'ordine:

- a) mediante l'inquadramento del personale trasferito dai ministeri e dagli enti pubblici, di cui al precedente articolo 8, comma 1;
- b) mediante le procedure di mobilita' di cui al capo III del titolo II del decreto legislativo 3 febbraio 1993, n. 29 e successive modificazioni ed integrazioni;
- c) a regime, mediante le ordinarie forme di reclutamento.

2. Al termine delle procedure di inquadramento di cui al precedente comma 1, sono corrispondentemente ridotte le dotazioni organiche delle amministrazioni e degli enti di provenienza e le corrispondenti risorse finanziarie sono trasferite all'agenzia. In ogni caso, le suddette dotazioni organiche non possono essere reintegrate.

3. Al personale inquadrato nell'organico dell'agenzia, ai sensi del precedente comma 1, e' mantenuto il trattamento giuridico ed economico spettante presso gli enti, le amministrazioni e gli organismi di provenienza al momento dell'inquadramento, fino alla stipulazione del primo contratto integrativo collettivo di ciascuna agenzia.

4. Gli oneri di funzionamento dell'agenzia sono coperti:

- a) mediante le risorse finanziarie trasferite da amministrazioni secondo quanto disposto dal precedente comma 2;
- b) mediante gli introiti derivanti dai contratti stipulati con le amministrazioni per le prestazioni di collaborazione, consulenza, assistenza, servizio, supporto, promozione;
- c) mediante un finanziamento annuale, nei limiti del fondo a tale scopo stanziato in apposita unita' previsionale di base dello stato di previsione dei ministero competente e suddiviso in tre capitoli, distintamente riferiti agli oneri di gestione, calcolati tenendo conto dei vincoli di servizio, alle spese di investimento, alla quota incentivante connessa al raggiungimento degli obiettivi gestionali.

### Art. 10. - (Agenzie fiscali)

1. Le agenzie fiscali sono disciplinate, anche in deroga agli articoli 8 e 9, dalle disposizioni del Capo II del Titolo V del presente decreto legislativo ed alla loro istituzione si provvede secondo le modalita' e nei termini ivi previsti. ((26))

--------------- AGGIORNAMENTO (26) Il D.L. 31 maggio 2005, n. 90, convertito con modificazioni dalla L. 26 luglio 2005, n. 152, nel modificare l'art. 1 del D.L. 7 settembre 2001, n. 343, convertito con modificazioni dalla L. 9 novembre 2001, n. 401, ha conseguentemente disposto (con l'art. 4, comma 1) che le disposizioni previste dal presente articolo, limitatamente alle politiche di protezione civile, recanti riferimenti al Ministro od al Ministero dell'interno, sono conseguentemente abrogate.

## L'AMMINISTRAZIONE PERIFERICA

### Art. 11.

(( (Prefettura - Ufficio Territoriale del Governo). )) ((

1. La Prefettura assume la denominazione di Prefettura-Ufficio territoriale del Governo.

2. La Prefettura-Ufficio territoriale del Governo, ferme restando le proprie funzioni, assicura l'esercizio coordinato dell'attivita' amministrativa degli uffici periferici dello Stato e garantisce la leale collaborazione di detti uffici con gli enti locali. Sono in ogni caso fatte salve le competenze spettanti alle regioni a statuto speciale ed alle province autonome.

3. Fermo restando quanto previsto dall'articolo 10 della legge 5 giugno 2003, n. 131, ai fini di cui al comma 2, il Prefetto, titolare della Prefettura-Ufficio territoriale del Governo, e' coadiuvato da una conferenza provinciale permanente, dallo stesso presieduta e composta dai responsabili di tutte le strutture amministrative periferiche dello Stato che svolgono la loro attivita' nella provincia nonche' da rappresentanti degli enti locali. Il Prefetto titolare della Prefettura-Ufficio territoriale del Governo nel capoluogo della regione e' altresi' coadiuvato da una conferenza permanente composta dai rappresentanti delle strutture periferiche regionali dello Stato, alla quale possono essere invitati i rappresentanti della regione.

4. Nell'esercizio delle funzioni di coordinamento previste dai commi 2 e 3 il Prefetto, sia in sede di conferenza provinciale sia con interventi diretti, puo' richiedere ai responsabili delle strutture amministrative periferiche dello Stato l'adozione di provvedimenti volti ad evitare un grave pregiudizio alla qualita' dei servizi resi alla cittadinanza anche ai fini del rispetto della leale collaborazione con le autonomie territoriali. Nel caso in cui non vengano assunte nel termine indicato le necessarie iniziative, il Prefetto, previo assenso del Ministro competente per materia, puo' provvedere direttamente, informandone preventivamente il Presidente del Consiglio dei Ministri.

5. Il Presidente del Consiglio dei Ministri ed i Ministri, nell'esercizio del potere di indirizzo politico-amministrativo, emanano, ove occorra, apposite direttive ai Prefetti.

6. Con regolamento da emanarsi ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, si provvede ad adottare le disposizioni per l'attuazione del presente articolo e per l'adeguamento della normativa regolamentare vigente.

## I MINISTERI CAPO I IL ((MINISTERO DEGLI AFFARI ESTERI E DELLA COOPERAZIONE INTERNAZIONALE))

### Art. 12. - (Attribuzioni)

1. Al Ministero degli affari esteri e della cooperazione internazionale sono attribuiti le funzioni e i compiti spettanti allo Stato in materia di rapporti politici, economici, sociali e culturali con l'estero; di rappresentanza, di coordinamento e di tutela degli interessi italiani in sede internazionale; di analisi, definizione e attuazione dell'azione italiana in materia di politica internazionale e di cooperazione allo sviluppo; di rapporti con gli altri Stati e con le organizzazioni internazionali; di stipulazione e di revisione dei trattati e delle convenzioni internazionali e di coordinamento delle relative attivita' di gestione; di studio e di risoluzione delle questioni di diritto internazionale, nonche' di contenzioso internazionale; di rappresentanza della posizione italiana in ordine all'attuazione delle disposizioni relative alla politica estera e di sicurezza comune previste dal Trattato sull'Unione europea e di rapporti attinenti alle relazioni politiche ed economiche estere dell'Unione europea; di emigrazione e tutela delle collettivita' italiane e dei lavoratori all'estero; di cura delle attivita' di integrazione europea in relazione alle istanze ed ai processi negoziali riguardanti i trattati sull'Unione europea; di definizione delle strategie e degli interventi della politica commerciale e promozionale con l'estero e di sostegno dell'internazionalizzazione del sistema Paese, ferme restando le competenze del Ministero dell'economia e delle finanze, del ((Ministero delle imprese e del made in Italy)) e delle regioni.

2. Nell'esercizio delle sue attribuzioni il Ministero degli affari esteri e della cooperazione internazionale assicura la coerenza delle attivita' internazionali ed europee delle singole amministrazioni con gli obiettivi di politica internazionale.

3. Restano attribuite alla presidenza del consiglio dei ministri le funzioni ad essa spettanti in ordine alla partecipazione dello Stato italiano all'Unione europea, nonche' all'attuazione delle relative politiche.

### Art. 13. - (Ordinamento)

1. Il ministero si articola in direzioni generali in numero non superiore a 20, coordinate da un segretario generale.

2. Restano in vigore, per il ((Ministero degli affari esteri e della cooperazione internazionale)), la riserva di cui all'articolo 6, comma 5, del decreto legislativo 3 febbraio 1993, n. 29, cosi' come modificato dal decreto legislativo 31 marzo 1998, n. 80, concernente le particolari disposizioni dettate dalle normative di settore e l'articolo 4 del decreto del Presidente della Repubblica 5 gennaio 1967, n.18.

### Art. 13-bis. - (( (Agenzia italiana per la cooperazione allo sviluppo).))

## IL MINISTERO DELL'INTERNO

### Art. 14. - (Attribuzioni)

1. Al Ministero dell'interno sono attribuite le funzioni e i compiti spettanti allo Stato in materia di: garanzia della regolare costituzione e del funzionamento degli organi degli enti locali e funzioni statali esercitate dagli enti locali, tutela dell'ordine e della sicurezza pubblica, difesa civile, politiche di protezione civile e prevenzione incendi, salve le specifiche competenze in materia del Presidente del Consiglio dei Ministri, tutela dei diritti civili, cittadinanza, immigrazione, asilo e soccorso pubblico. ((26))

2. Il ministero svolge in particolare le funzioni e i compiti di spettanza statale nelle seguenti aree funzionali:

- a) garanzia della regolare costituzione degli organi elettivi degli enti locali e del loro funzionamento, finanza locale, servizi elettorali, vigilanza sullo stato civile e sull'anagrafe e attivita' di collaborazione con gli enti locali;
- b) tutela dell'ordine e della sicurezza pubblica e coordinamento delle forze di polizia;
- c) amministrazione generale e supporto dei compiti di rappresentanza generale di governo sul territorio;
- d) tutela dei diritti civili, ivi compresi quelli delle confessioni religiose, di cittadinanza, immigrazione e asilo;
- d-bis) organizzazione e funzionamento delle strutture centrali e periferiche dell'amministrazione, con particolare riguardo alle politiche del personale dell'amministrazione civile e alla promozione e sviluppo delle relative attivita' formative nonche' alla gestione delle risorse strumentali e finanziarie del ministero.

3. Il ministero svolge attraverso il corpo nazionale dei vigili del fuoco anche gli altri compiti ad esso assegnati dalla normativa vigente. ((26))

4. Restano ferme le disposizioni della legge 1 aprile 1981, n. 121.

--------------- AGGIORNAMENTO (26) Il D.L. 31 maggio 2005, n. 90, convertito con modificazioni dalla L. 26 luglio 2005, n. 152, nel modificare l'art. 1 del D.L. 7 settembre 2001, n. 343, convertito con modificazioni dalla L. 9 novembre 2001, n. 401, ha conseguentemente disposto (con l'art. 4, comma 1) che le disposizioni previste dai commi 1 e 3 del presente articolo, limitatamente alle politiche di protezione civile, recanti riferimenti al Ministro od al Ministero dell'interno, sono conseguentemente abrogate.

### Art. 15. - (Ordinamento)

1. Il ministero si articola in dipartimenti, disciplinati ai sensi degli articoli 4 e 5 del presente decreto. Il numero dei dipartimenti non puo' essere ((superiore a cinque)).

2. L'organizzazione periferica del ministero e' costituita dagli Uffici territoriali del governo di cui all'articolo 11, anche con compiti di rappresentanza generale del governo sul territorio, dalle Questure e dalle strutture periferiche del corpo nazionale dei vigili del fuoco.

## IL MINISTERO DELLA GIUSTIZ1A

### Art. 16. - (Attribuzioni)

1. Il ministro di grazia e giustizia e il ministero di grazia e giustizia assumono rispettivamente la denominazione di ministro della giustizia e ministero della giustizia.

2. Il ministero della giustizia svolge le funzioni e i compiti ad esso attribuiti dalla Costituzione, dalle leggi e dai regolamenti in materia di giustizia e attivita' giudiziaria ed esecuzione delle pene, rapporti con il consiglio superiore della magistratura, attribuzioni concernenti i magistrati ordinari, vigilanza sugli ordini professionali, archivi notarili, cooperazione internazionale in materia civile e penale.

3. Il ministero esercita in particolare le funzioni e i compiti concernenti le seguenti aree funzionali:

- a) servizi relativi alla attivita' giudiziaria: gestione amministrativa della attivita' giudiziaria in ambito civile e penale; attivita' preliminare all'esercizio da parte del ministro delle sue competenze in materia processuale; casellario giudiziale; cooperazione internazionale in materia civile e penale; studio e proposta di interventi normativi nel settore di competenza;
- b) organizzazione e servizi della giustizia: organizzazione e funzionamento dei servizi relativi alla giustizia; gestione amministrativa del personale amministrativo e dei mezzi e strumenti necessari; attivita' relative alle competenze del ministro in ordine ai magistrati; studio e proposta di interventi normativi nel settore di competenza;
- c) servizi dell'amministrazione penitenziaria: gestione amministrativa del personale e dei beni della amministrazione penitenziaria; svolgimento dei compiti relativi alla esecuzione delle misure cautelari, delle pene e delle misure di sicurezza detentive; svolgimento dei compiti previsti dalle leggi per il trattamento dei detenuti e degli internati;
- d-bis) servizi per la transizione digitale della giustizia, l'analisi statistica e le politiche di coesione: gestione dei processi e delle risorse connessi alle tecnologie dell'informazione, della comunicazione e della innovazione; gestione della raccolta, organizzazione e analisi dei dati relativi a tutti i servizi connessi all'amministrazione della giustizia; attuazione delle procedure di raccolta dei dati e della relativa elaborazione statistica secondo criteri di completezza, affidabilita', trasparenza e pubblicita'; monitoraggio dell'efficienza del servizio giustizia con particolare riferimento alle nuove iscrizioni, alle pendenze e ai tempi di definizione dei procedimenti negli uffici giudiziari; coordinamento della programmazione delle attivita' della politica regionale, nazionale e comunitaria e di coesione.

3-bis. Per l'esercizio delle funzioni e dei compiti indicati al comma 3, il Ministero della giustizia, fermo il disposto dell'articolo 4, comma 10, del decreto-legge 29 dicembre 2009, n. 193, convertito, con modificazioni, dalla legge 22 febbraio 2010, n. 24, provvede ad effettuare l'accesso diretto ai dati relativi a tutti i servizi connessi all'amministrazione della giustizia, anche se raccolti dagli uffici giudiziari.

4. Relativamente all'ispettorato generale restano salve le disposizioni della legge 12 agosto 1962, n. 1311 e successive modifiche ed integrazioni, nonche' dell'articolo 8 della legge 24 marzo 1958, n. 195.

### Art. 17. - (Ordinamento)

1. Il ministero si articola in dipartimenti, disciplinati ai sensi degli articoli 4 e 5 del presente decreto. Il numero dei dipartimenti non puo' essere superiore a ((cinque)), in riferimento alle aree funzionali definite nel precedente articolo.

### Art. 18. - (incarichi dirigenziali)

1. Agli uffici di diretta collaborazione con il ministro ed ai dipartimenti, sono preposti i dirigenti di cui all'articolo 23 del decreto legislativo 3 febbraio 1993, n. 29, come sostituito dall'articolo 15 del decreto legislativo 31 marzo 1998, n. 80, i magistrati delle giurisdizioni ordinarie e amministrative, i professori e ricercatori universitari gli avvocati dello Stato, gli avvocati; quando ricorrono specifiche esigenze di servizio, ai medesimi uffici possono essere preposti anche soggetti estranei all'amministrazione ai sensi dell'articolo 19, comma 6, del decreto legislativo 3 febbraio 1993, n. 29, come sostituito dall'articolo 23 del decreto legislativo 31 marzo 1998, n. 80.

2. Agli uffici dirigenziali generali istituiti all'interno dei dipartimenti, sono preposti i dirigenti di cui all'articolo 23 del decreto legislativo 3 febbraio 1993, n. 29, come sostituito dall'articolo 15 del decreto legislativo 31 marzo 1998, n. 80, ed i magistrati della giurisdizione ordinaria; quando ricorrono specifiche esigenze di servizio, ai medesimi uffici possono essere preposti anche gli altri soggetti elencati al comma l.

### Art. 19.

(( (Magistrati). )) ((

1. Il numero massimo dei magistrati collocati fuori dal ruolo organico della magistratura e destinati al Ministero non deve superare le 65 unita'. )) ((21))

----------------- AGGIORNAMENTO (8) Il D.L. 11 novembre 2002, n. 251, convertito con modificazioni dalla L. 10 gennaio 2003, n. 1 ha disposto (con l'art. 5, comma 1) che al fine di assicurare il necessario supporto tecnico all'attivita' del Governo in occasione del semestre di Presidenza italiana dell'Unione europea, il numero massimo dei magistrati che possono essere collocati fuori dal ruolo organico della magistratura per essere destinati al Ministero della giustizia, ai sensi del presente articolo, e' elevato da 50 a 62 unita' fino al 30 giugno 2004. ----------------- AGGIORNAMENTO (21) Il D.L. 24 dicembre 2003, n. 354, convertito con modificazioni dalla L. 26 febbraio 2004, n. 45 ha disposto (con l'art. 1-bis, comma 1) che tale modifica ha effetto dal 1° luglio 2004.

## IL MINISTERO DELLA DIFESA

### Art. 20. - (Attribuzioni)

1. Al ministero della difesa sono attribuite le funzioni e i compiti spettanti allo Stato in materia di difesa e sicurezza militare dello Stato, politica militare e partecipazione a missioni a supporto della pace, partecipazione ad organismi internazionali di settore, pianificazione generale e operativa delle forze armate e interforze, pianificazione relativa all'area industriale di interesse della difesa.

((

2. Il Ministero esercita in particolare le funzioni e i compiti di cui all'articolo 15 del codice dell'ordinamento militare di cui al decreto legislativo 15 marzo 2010, n. 66.

))

### Art. 21. - (Ordinamento)

1. Il ministero si articola in direzioni generali in numero non superiore a undici , coordinate da un segretario generale.

((

2. L'articolazione del Ministero e' definita dall'articolo 16 del codice dell'ordinamento militare.

))

### Art. 22. - (( (Agenzia industrie difesa) ))

((

1. I compiti e le funzioni dell'Agenzia industrie difesa sono definiti dall'articolo 48 del codice dell'ordinamento militare.

))

## IL MINISTERO DELL'ECONOMIA E DELLE FINANZE

### Art. 23. - (Istituzione del ministero e attribuzioni)

1. E' istituito il ministero dell'economia e delle finanze.

2. Al ministero sono attribuite le funzioni e i compiti spettanti allo Stato in materia di politica economica, finanziaria e di bilancio, programmazione degli investimenti pubblici, coordinamento della spesa pubblica e verifica dei suoi andamenti, ivi incluso il settore della spesa sanitaria, politiche fiscali e sistema tributario, ((comprese l'organizzazione dei servizi della giustizia tributaria e la gestione amministrativa a supporto dell'attivita' giudiziaria tributaria,)) demanio e patrimonio statale, catasto e dogane Il ministero svolge altresi' i compiti di vigilanza su enti e attivita' e le funzioni relative ai rapporti con autorita' di vigilanza e controllo previsti dalla legge.

3. Al ministero sono trasferite con le inerenti risorse, le funzioni dei ministeri del tesoro, bilancio e programmazione economica e delle finanze, eccettuate quelle attribuite, anche dal presente decreto, ad altri ministeri o ad agenzie e fatte in ogni caso salve, ai sensi e per gli effetti degli articoli 1, comma 2, e 3, comma 1, lettere a) e b) della legge 15 marzo 1997,n. 59, le funzioni conferite dalla vigente legislazione alle regioni ed agli enti locali e alle autonomie funzionali.

### Art. 24. - (Aree funzionali)

1. Il ministero svolge, in particolare, le funzioni di spettanza statale nelle seguenti aree funzionali:

- a) politica economica e finanziaria, con particolare riguardo all'analisi dei problemi economici, monetari e finanziari interni e internazionali, alla vigilanza sui mercati finanziari e sul sistema creditizio, all'elaborazione delle linee di programmazione economica e finanziaria, alle operazioni di copertura del fabbisogno finanziario e di gestione del debito pubblico; alla valorizzazione dell'attivo e del patrimonio dello Stato alla gestione di partecipazioni azionarie dello Stato, compreso l'esercizio dei diritti dell'azionista e l'alienazione dei titoli azionari di proprieta' dello Stato, alla monetazione; alla prevenzione delle frodi sui mezzi di pagamento diversi dalla moneta nonche' sugli strumenti attraverso i quali viene erogato il credito al consumo e dell'utilizzazione del sistema finanziario a scopo di riciclaggio, ferme restando le competenze del Ministero dell'interno in materia;
- b) politiche, processi e adempimenti di bilancio, con particolare riguardo alla formazione e gestione del bilancio dello Stato, compresi gli adempimenti di tesoreria e la verifica dei relativi andamenti e flussi di cassa, assicurandone il raccordo operativo con gli adempimenti in materia di copertura del fabbisogno finanziario previsto dalla lettera a), nonche' alla verifica della quantificazione degli oneri derivanti dai provvedimenti e dalle innovazioni normative ed al monitoraggio della spesa pubblica ivi inclusi tutti i profili attinenti al concorso dello Stato al finanziamento del Servizio sanitario nazionale, anche quanto ai piani di rientro regionali, coordinandone e verificandone gli andamenti e svolgendo i controlli previsti dall'ordinamento, ivi comprese le funzioni ispettive ed i controlli di regolarita' amministrativa e contabile effettuati, ai sensi della normativa vigente, dagli Uffici centrali del bilancio costituiti presso i Ministeri e dalle ragionerie provinciali dello Stato;
- c) programmazione economica e finanziaria, coordinamento e verifica degli interventi per lo sviluppo economico territoriale e settoriale e delle politiche di coesione, anche avvalendosi delle Camere di commercio, con particolare riferimento alle aree depresse, esercitando a tal fine le funzioni attribuite dalla legge in materia di strumenti di programmazione negoziata e di programmazione dell'utilizzo dei fondi strutturali comunitari;
- d) politiche fiscali con particolare riguardo alle funzioni di cui all'articolo 56, all'analisi del sistema fiscale e delle scelte inerenti alle entrate tributarie ed erariali in sede nazionale, comunitaria e internazionale, alle attivita' di coordinamento, indirizzo, vigilanza e controllo previste dalla legge sulle agenzie fiscali e sugli altri enti o organi che comunque esercitano funzioni in materia di tributi ed entrate erariali di competenza dello Stato, al coordinamento monitoraggio e controllo del sistema informativo della fiscalita' e della rete unitaria di settore, alla informazione istituzionale nel settore della fiscalita', alle funzioni previste dalla legge in materia di demanio, catasto e conservatorie dei registri immobiliari;
- e) amministrazione generale, servizi indivisibili e comuni del Ministero, con particolare riguardo alle attivita' di promozione, coordinamento e sviluppo della qualita' dei processi e dell'organizzazione e alla gestione delle risorse; linee generali e coordinamento delle attivita' concernenti il personale del Ministero; affari generali ed attivita' di gestione del personale del Ministero di carattere comune ed indivisibile; programmazione generale del fabbisogno del Ministero e coordinamento delle attivita' in materia di reclutamento del personale del Ministero; rappresentanza della parte pubblica nei rapporti sindacali all'interno del Ministero; tenuta della banca dati, del ruolo e del sistema informativo del personale del Ministero; tenuta dell'anagrafe degli incarichi del personale del Ministero; servizi del tesoro, incluso il pagamento delle retribuzioni, ed acquisti centralizzati; coordinamento della comunicazione istituzionale del Ministero.

1-bis. Le funzioni in materia di organizzazione, programmazione del fabbisogno, reclutamento, formazione e gestione del personale delle singole aree sono svolte nell'ambito delle stesse aree.

### Art. 25. - (Ordinamento)

1. Il ministero si articola in dipartimenti, disciplinati ai sensi degli articoli 4 e 5 del presente decreto. Il numero dei dipartimenti non puo' essere superiore a ((sei)), in riferimento alle aree funzionali definite nel precedente articolo. Il Servizio consultivo ed ispettivo tributario opera alle dirette dipendenze del Ministro.

2. L'Amministrazione autonoma dei Monopoli di Stato, disciplinata ai sensi dell'articolo 4 del presente decreto legislativo, svolge le funzioni attribuite al Ministero dell'economia e delle finanze in materia di giochi, scommesse e concorsi pronostici, ivi comprese quelle riguardanti i relativi tributi, fatta eccezione per le imposte dirette e l'imposta sul valore aggiunto, nonche' in materia di amministrazione, riscossione e contenzioso concernenti le accise sui tabacchi lavorati. (15)

--------------- AGGIORNAMENTO (15) Il D.L. 30 settembre 2003, n. 269, convertito con modificazioni dalla L. 24 novembre 2003, n. 326, ha disposto (con l'art. 39, comma 13-ter) che ferme restando le attribuzioni del Ministero delle attivita' produttive in materia di concorsi ed operazioni a premio, le disposizioni in tema di attribuzione unitaria al Ministero dell'economia e delle finanze-Amministrazione autonoma dei monopoli di Stato delle funzioni statali in materia di organizzazione e gestione dei giuochi, ed in particolare quelle introdotte con il comma 2 del presente articolo, si intendono nel senso che tra le predette funzioni rientrano quelle di controllo sulle attivita' che costituiscono, per la mancanza di reali scopi promozionali, elusione del monopolio statale dei giuochi.

### Art. 26. - (Riforma del ministero delle finanze)

1. In attesa della costituzione del ministero dell'economia e delle finanze, e comunque entro il termine di diciotto mesi dalla data dell'entrata in vigore del presente decreto legislativo, si provvede anche in fasi successive, alla trasformazione del ministero delle finanze, alla istituzione delle agenzie fiscali e all'ordinato trasferimento delle funzioni e delle risorse, secondo le disposizioni e con le modalita' stabilite dal Capo II del Titolo V.

## ((MINISTERO DELLE IMPRESE E DEL MADE IN ITALY))

### Art. 27.

(( (Attribuzioni) ))

1. ((COMMA ABROGATO DAL D.L. 11 NOVEMBRE 2022, N. 173)).

2. ((Il Ministero delle imprese e del made in Italy)), ferme restando le competenze del Presidente del Consiglio dei Ministri, ha lo scopo di formulare e attuare politiche e strategie per lo sviluppo del sistema produttivo, ivi inclusi gli interventi in favore delle aree sottoutilizzate, secondo il principio di sussidiarieta' e di leale collaborazione con gli enti territoriali interessati e in coerenza con gli obiettivi generali di politica industriale e, in particolare, di:

- a) promuovere le politiche per la competitivita' internazionale, in coerenza con le linee generali di politica estera e lo sviluppo economico del sistema produttivo nazionale e di realizzarle o favorirne l'attuazione a livello settoriale e territoriale, anche mediante la partecipazione, fatte salve le competenze del Ministero dell'economia e delle finanze e per il tramite dei rappresentanti italiani presso tali organizzazioni, alle attivita' delle competenti istituzioni internazionali;
- b) sostenere e integrare l'attivita' degli enti territoriali per assicurare l'unita' economica del Paese;
- c) promuovere la concorrenza;
- d) coordinare le istituzioni pubbliche e private interessate allo sviluppo della competitivita';
- e) monitorare l'impatto delle misure di politica economica, industriale, infrastrutturale, sociale e ambientale sulla competitivita' del sistema produttivo.

2-bis. Per realizzare gli obiettivi indicati al comma 2, il Ministero, secondo il principio di sussidiarieta' e di leale collaborazione con gli enti territoriali interessati:

- a) definisce, anche in concorso con le altre amministrazioni interessate, le strategie per il miglioramento della competitivita', anche a livello internazionale, del Paese e per la promozione della trasparenza e dell'efficacia della concorrenza nei settori produttivi, collaborando all'attuazione di tali orientamenti;
- b) promuove, in coordinamento con il Dipartimento di cui all'articolo 3, comma 2, del decreto legislativo 30 luglio 1999, n. 303, gli interessi del sistema produttivo del Paese presso le istituzioni internazionali e comunitarie di settore e facendo salve le competenze del Ministero dell'economia e delle finanze e del Ministero degli affari esteri e della cooperazione internazionale e per il tramite dei rappresentanti italiani presso tali organismi;
- c) definisce le politiche per lo sviluppo economico e per favorire l'assunzione, da parte delle imprese, di responsabilita' relative alle modalita' produttive, alla qualita' e alla sicurezza dei prodotti e dei servizi, alle relazioni con il consumatore;
- d) studia la struttura e l'andamento dell'economia industriale e aziendale;
- e) LETTERA ABROGATA DAL D.L. 21 SETTEMBRE 2019, N. 104.

2-ter. Il Ministero elabora ogni triennio, sentite le amministrazioni interessate ed aggiornandolo con cadenza annuale, un piano degli obiettivi, delle azioni e delle risorse necessarie per il loro raggiungimento, delle modalita' di attuazione, delle procedure di verifica e di monitoraggio.

2-quater. Restano in ogni caso ferme le attribuzioni degli altri Ministeri e della Presidenza del Consiglio dei Ministri.

3. Al Ministero sono trasferite, con le inerenti risorse, le funzioni del Ministero dell'industria, del commercio e dell'artigianato, del Ministero del commercio con l'estero, fatte salve le risorse e il personale che siano attribuiti con il presente decreto legislativo ad altri Ministeri, agenzie o autorita', perche' concernenti funzioni specificamente assegnate ad essi, e fatte in ogni caso salve, ai sensi e per gli effetti degli articoli 1, comma 2, e 3, comma 1, lettere a) e b), della legge 15 marzo 1997, n. 59, le funzioni conferite dalla vigente legislazione alle regioni ed agli enti locali e alle autonomie funzionali.

4. Spettano inoltre al Ministero delle attivita' produttive le risorse e il personale del Ministero del tesoro, del bilancio e della programmazione economica, del Ministero della sanita', del Ministero del lavoro e della previdenza sociale, concernenti le funzioni assegnate al Ministero delle attivita' produttive dal presente decreto legislativo.

5. Restano ferme le competenze spettanti al Ministero della difesa.

### Art. 28.

(Aree funzionali).

1. Nel rispetto delle finalita' e delle azioni di cui all'articolo 27, il Ministero, ferme restando le competenze del Presidente del Consiglio dei Ministri, svolge per quanto di competenza, in particolare le funzioni e i compiti di spettanza statale nelle seguenti aree funzionali:

- a) competitivita': politiche per lo sviluppo della competitivita' del sistema produttivo nazionale; politiche di promozione degli investimenti delle imprese al fine del superamento degli squilibri di sviluppo economico e tecnologico, ivi compresi gli interventi a sostegno delle attivita' produttive e gli strumenti della programmazione negoziata, denominati contratti di programma, inclusi quelli ricompresi nell'ambito dei contratti di localizzazione, patti territoriali, contratti d'area e contratti di distretto, nonche' la partecipazione, per quanto di competenza ed al pari delle altre amministrazioni, agli accordi di programma quadro, ed il raccordo con gli interventi degli enti territoriali, rispondenti alle stesse finalita'; politiche per le piccole e medie imprese, per la creazione di nuove imprese e per il sostegno alle imprese ad alto tasso di crescita, tenendo conto anche delle competenze regionali; politiche di supporto alla competitivita' delle grandi imprese nei settori strategici; collaborazione pubblico-privato nella realizzazione di iniziative di interesse nazionale, nei settori di competenza; politiche per i distretti industriali; sviluppo di reti nazionali e internazionali per l'innovazione di processo e di prodotto nei settori produttivi; attivita' di regolazione delle crisi aziendali e delle procedure conservative delle imprese; attivita' di coordinamento con le societa' e gli istituti operanti in materia di promozione industriale e di vigilanza sull'Istituto per la promozione industriale; politica industriale relativa alla partecipazione italiana al Patto atlantico e all'Unione europea; collaborazione industriale internazionale nei settori aerospaziali e della difesa, congiuntamente agli altri Ministeri interessati; monitoraggio sullo stato dei settori merceologici, ivi compreso, per quanto di competenza, il settore agro-industriale, ed elaborazione di politiche per lo sviluppo degli stessi; iniziative finalizzate all'ammodernamento di comparti produttivi e di aree colpite dalla crisi di particolari settori industriali; politiche per l'integrazione degli strumenti di agevolazione alle imprese nel sistema produttivo nazionale; vigilanza ordinaria e straordinaria sulle cooperative; politiche per la promozione e lo sviluppo della cooperazione e mutualita';
- b) LETTERA ABROGATA DAL D.L. 21 SETTEMBRE 2019, N. 104;
- c) sviluppo economico: ((...)) organizzazione articolata delle attivita' per i brevetti, i modelli industriali e per marchi di impresa e relativi rapporti con le autorita' internazionali, congiuntamente con il Ministero degli affari esteri e della cooperazione internazionale per la parte di competenza; politiche di sviluppo per l'innovazione tecnologica nei settori produttivi; politiche di incentivazione per la ricerca applicata e l'alta tecnologia; politiche per la promozione e lo sviluppo del commercio elettronico; partecipazione ai procedimenti di definizione delle migliori tecnologie disponibili per i settori produttivi; politiche nel settore delle assicurazioni e rapporti con l'ISVAP, per quanto di competenza; promozione della concorrenza nel settore commerciale, attivita' di sperimentazione, monitoraggio e sviluppo delle nuove forme di commercializzazione, al fine di assicurare il loro svolgimento unitario; coordinamento tecnico per la valorizzazione e armonizzazione del sistema fieristico nazionale; disciplina ed attuazione dei rapporti commerciali e della loro evoluzione, nel rispetto dell'ordinamento civile e della tutela della concorrenza; sostegno allo sviluppo della responsabilita' sociale dell'impresa, con particolare riguardo ai rapporti con fornitori e consumatori e nel rispetto delle competenze delle altre amministrazioni; sicurezza e qualita' dei prodotti e degli impianti industriali ad esclusione dei profili di sicurezza nell'impiego sul lavoro e di vigilanza sugli enti di normazione tecnica e di accreditamento degli organismi di certificazione di qualita' e dei laboratori di prova per quanto di competenza; partecipazione al sistema di certificazione ambientale, in particolare in materia di ecolabel e ecoaudit; qualita' dei prodotti, ad esclusione di quelli agricoli e di prima trasformazione di cui all'allegato I del Trattato istitutivo della Comunita' economica europea, sicurezza dei prodotti, etichettatura e qualita' dei servizi destinati al consumatore, ferme le competenze delle regioni in materia di commercio; metrologia legale e determinazione del tempo; politiche per i consumatori e connessi rapporti con l'Unione europea, ferme restando le competenze del Presidente del Consiglio dei Ministri, gli organismi internazionali e gli enti locali; attivita' di supporto e segreteria tecnico-organizzativa del Consiglio nazionale dei consumatori e degli utenti (CNCU); attivita' di tutela dei consumatori nel settore turistico a livello nazionale; monitoraggio dei prezzi liberi e controllati nelle varie fasi di scambio ed indagini sulle normative, sui processi di formazione dei prezzi e delle condizioni di offerta di beni e servizi; controllo e vigilanza delle manifestazioni a premio, ferme le attribuzioni del Ministero dell'economia e finanze - Amministrazione autonoma dei monopoli di Stato - in materia di giochi, nonche' di prevenzione e repressione dei fenomeni elusivi del relativo monopolio statale; vigilanza sul sistema delle camere di commercio, industria, artigianato e agricoltura, secondo quanto disposto dal decreto legislativo 31 marzo 1998, n. 112, e sulla tenuta del registro delle imprese; politiche per lo sviluppo dei servizi nei settori di competenza; vigilanza sulle societa' fiduciarie e di revisione nei settori di competenza.

2. Il Ministero svolge altresi' compiti di studio, consistenti in particolare nelle seguenti attivita': redazione del piano triennale di cui al comma 2-ter dell'articolo 27; ricerca e rilevazioni economiche riguardanti i settori produttivi ed elaborazione di iniziative, ivi compresa la definizione di forme di incentivazione dei relativi settori produttivi, finalizzate a incrementare la competitivita' del sistema produttivo nazionale; valutazione delle ricadute industriali conseguenti agli investimenti pubblici; coordinamento informatico-statistico dei dati relativi agli interventi di agevolazione assunti in sede di Unione europea, nazionale e regionale, anche ai fini del monitoraggio e della valutazione degli effetti sulla competitivita' del sistema produttivo nazionale; ricerca in materia di tutela dei consumatori e degli utenti; monitoraggio dell'attivita' assicurativa anche ai fini delle iniziative legislative in materia; ricerche, raccolta ed elaborazione di dati e rilevazioni economiche riguardanti il sistema turistico; rilevazione degli aspetti socio-economici della cooperazione.

3. Restano in ogni caso ferme le competenze degli altri Ministeri.

### Art. 29.

(Ordinamento).

1. Il Ministero si articola ((in non piu' di quattro dipartimenti e)) in non piu' di nove direzioni generali, alla cui individuazione e organizzazione si provvede ai sensi dell'articolo 4, sentite le organizzazioni sindacali maggiormente rappresentative, e in modo che sia assicurato il coordinamento delle aree funzionali previste all'articolo 28.

2. Il Ministero delle imprese e del made in Italy si avvale degli uffici territoriali di Governo, nonche', sulla base di apposite convenzioni, delle camere di commercio, industria, artigianato e agricoltura.

### Art. 30. - (Attribuzioni di funzioni ad altri ministeri)

1. Le funzioni inerenti ai rapporti con l'istituto per la vigilanza delle assicurazioni private e di interesse pubblico, attualmente esercitate dal ministero dell'industria, del commercio e dell'artigianato sono trasferite al ministero del tesoro, del bilancio e della programmazione economica. Il relativo personale e le risorse relative sono assegnati al ministero del tesoro, del bilancio e della programmazione economica.

### Art. 31.

(( ARTICOLO ABROGATO DAL D.LGS. 22 GENNAIO 2004, N. 34 ))

### Art. 32.

(( ARTICOLO ABROGATO DAL D.LGS. 22 GENNAIO 2004, N. 34 ))

## MINISTERO DELLE COMUNICAZIONI))

### Art. 32-bis.

(( (Istituzione del Ministero e attribuzioni). )) ((

1. E' istituito il Ministero delle comunicazioni.

2. Al Ministero sono attribuite le funzioni e i compiti spettanti allo Stato in materia di poste, telecomunicazioni, reti multimediali, informatica, telematica, radiodiffusione sonora e televisiva, tecnologie innovative applicate al settore delle comunicazioni, ferme restando le competenze in materia di stampa ed editoria del Dipartimento per l'informazione e l'editoria della Presidenza del Consiglio dei Ministri. Restano ferme le competenze dell'Autorita' per le garanzie nelle comunicazioni.

### Art. 32-ter.

(( (Funzioni). )) ((

1. Il Ministero svolge in particolare funzioni e compiti di spettanza statale nelle seguenti aree funzionali, tramite gli organi centrali e gli Ispettorati territoriali:

- a) politiche nel settore delle comunicazioni;
- b) rapporti con l'Unione europea e con le organizzazioni e le agenzie internazionali nel settore delle comunicazioni, ferme restando le competenze del Presidente del Consiglio dei Ministri di cui al decreto legislativo 30 luglio 1999, n. 303, e del Ministro degli affari esteri;
- c) disciplina del settore delle comunicazioni elettroniche;
- d) gestione nazionale di programmi comunitari in materia di comunicazioni elettroniche;
- e) radiodiffusione sonora e televisiva pubblica e privata anche nelle forme evolutive;
- f) regolamentazione dei servizi postali, con particolare riferimento al contratto di programma con il fornitore del servizio universale;
- g) emissione delle carte valori postali;
- h) formazione e addestramento professionale anche tramite la Scuola superiore di specializzazione in telecomunicazioni;
- i) concessioni, licenze e autorizzazioni nei settori delle comunicazioni;
- l) controllo del mercato, vigilanza sul rispetto delle normative di settore e applicazione delle sanzioni;
- m) adeguamento periodico del servizio universale nel campo delle comunicazioni;
- n) verifica degli obblighi di servizio universale nei settori delle comunicazioni;
- o) tutela delle comunicazioni;
- p) piano nazionale di ripartizione delle frequenze e relativa attivita' internazionale;
- q) gestione degli accordi internazionali in materia di assegnazione dei diritti d'uso delle frequenze e delle reti ed orbite dei sistemi satellitari e notifica all'Unione internazionale delle telecomunicazioni;
- r) assegnazione dei diritti d'uso delle frequenze e delle numerazioni;
- s) controllo delle emissioni radioelettriche e delle interferenze;
- t) tecnologie dell'informazione; sicurezza delle reti; studi e ricerca scientifica nei settori delle comunicazioni e delle tecnologie dell'informazione (ICT); normazione tecnica, ivi compresi gli aspetti inerenti alla numerazione, standardizzazione, anche quale organismo nazionale di standardizzazione (NSO), accreditamento, certificazione ed omologazione nei settori dell'ICT; definizione degli standard di qualita' dei servizi nei settori dell'ICT; coordinamento della ricerca applicata per le tecnologie innovative nei settori dell'ICT e per l'adozione e l'implementazione di nuovi standard. Restano ferme le competenze e le funzioni attribuite al Presidente del Consiglio dei Ministri e al Ministro per l'innovazione e le tecnologie;
- u) servizi multimediali, con particolare riferimento alle iniziative volte alla trasformazione su supporti innovativi e con tecniche interattive delle produzioni tradizionali;
- v) certificazione per i prodotti e i sistemi informatici commerciali;
- z) adozione delle regole di impiego degli apparati radioelettrici;
- aa) espletamento di prestazioni per conto terzi;
- bb) rilascio dei titoli di abilitazione all'esercizio delle stazioni radioelettriche;
- cc) attivita' di collaudo ed ispezione delle apparecchiature radioelettriche di bordo;
- dd) vigilanza e controllo sugli enti operanti nell'ambito delle comunicazioni;
- ee) agevolazioni all'editoria, ferme restando le competenze del Dipartimento per l'informazione e l'editoria della Presidenza del Consiglio dei Ministri e del Ministero delle attivita' produttive.

2. Nelle materie proprie del Ministero delle comunicazioni l'accertamento delle violazioni e l'applicazione delle relative sanzioni amministrative sono espletati dagli uffici centrali e periferici del Ministero stesso, nell'ambito delle rispettive competenze, ferme restando le funzioni spettanti agli organi di polizia. L'ordinanza - ingiunzione, di cui al secondo comma dell'articolo 18 della legge 24 novembre 1981, n. 689, e' adottata nel termine di 180 giorni dalla scadenza del termine indicato nel primo comma dell'articolo 16 della medesima legge.

### Art. 32-quater.

(Organizzazione del Ministero).

1. Il Ministero si articola in uffici centrali di livello dirigenziale generale ed in ispettorati territoriali di livello dirigenziale non generale. Opera nell'ambito del Ministero e sotto la sua vigilanza l'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione, di livello dirigenziale generale". 2. Sono uffici centrali: a) il Segretariato generale; b) le direzioni generali, in numero di cinque cosi' individuate: 1) direzione generale per la gestione delle risorse umane; 2) direzione generale per la pianificazione e la gestione dello spettro radioelettrico; 3) direzione generale per i servizi di comunicazione elettronica e di radiodiffusione; 4) direzione generale per la regolamentazione del settore postale; 5) direzione generale per la gestione delle risorse strumentali ed informative. 3. Sono, altresi', previste tre posizioni di livello dirigenziale generale anche per l'assolvimento di compiti di coordinamento di progetti speciali, di ispezione, di controllo, nonche' di studio e di ricerca. (32) 4. Sono organi tecnici del Ministero: a) il Consiglio superiore delle comunicazioni; b) (( LETTERA ABROGATA DAL D.P.R. 14 MAGGIO 2007, N. 72 )); c) la Consulta per l'emissione di carte valori postali e la filatelia; d) (( LETTERA ABROGATA DAL D.P.R. 14 MAGGIO 2007, N. 72 )); e) la commissione consultiva nazionale di cui all'articolo 14 del decreto legislativo 9 maggio 2001, n. 269. 5. L'assetto organizzativo di cui al presente articolo puo' essere modificato con regolamento ai sensi dell'articolo 4 del decreto legislativo 30 luglio 1999, n. 300, e successive modificazioni, senza "oneri aggiuntivi".

--------------- AGGIORNAMENTO (32) Il D.P.R. 29 dicembre 2006, n. 309 ha disposto (con l'art. 5, comma 2) che al fine di assicurare l'effettivo rispetto del principio dell'invarianza della spesa, l'onere derivante dal trattamento economico spettante al Capo della Segreteria tecnica e' compensato sopprimendo contestualmente alla nomina una delle tre posizioni di livello dirigenziale generale di cui al comma 3 del presente articolo.

### Art. 32-quinquies.

(( (Struttura del Ministero). )) ((

1. Con uno o piu' decreti del Presidente della Repubblica, da emanare ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, n. 400, si provvede all'organizzazione degli uffici centrali.

2. Per l'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione si applicano i principi di autonomia organizzativa ed amministrativa dettati dall'articolo 41, commi 1 e 2 della legge 16 gennaio 2003, n. 3. L'Istituto espleta i compiti affidatigli dalla disciplina vigente, attenendosi agli indirizzi stabiliti dal Ministero delle comunicazioni; dispone, nell'ambito della dotazione organica del Ministero, di un apposito contingente di personale; agisce con piena autonomia scientifica e provvede all'autonoma gestione delle risorse iscritte in un unico capitolo dello stato di previsione della spesa del Ministero delle comunicazioni. Organi dell'Istituto sono il comitato amministrativo, il comitato tecnico-scientifico ed il direttore.

3. Con i decreti di cui al comma 1 si provvede altresi' al riordino della Scuola superiore di specializzazione in telecomunicazioni annessa all'Istituto di cui al comma 2.

## ((MINISTERO DELL'AGRICOLTURA, DELLA SOVRANITA' ALIMENTARE E DELLE FORESTE))

### Art. 33. - (Attribuzioni)

1. COMMA ABROGATO DAL D.L. 11 NOVEMBRE 2022, N. 173, CONVERTITO CON MODIFICAZIONI DALLA L. 16 DICEMBRE 2022, N. 204.

2. Sono attribuiti al Ministero dell'agricoltura, della sovranita' alimentare e delle foreste le funzioni e i compiti spettanti allo Stato in materia di agricoltura e foreste, caccia e pesca, ai sensi dell'articolo 2 del decreto legislativo 4 giugno 1997, n.143, fatto salvo quanto previsto dagli articoli 25 e 26 del presente decreto legislativo. Sono altresi' attribuiti al ministero le funzioni e i compiti spettanti allo Stato in materia di tutela della sovranita' alimentare, ((che esso esercita)) garantendo la sicurezza delle scorte e degli approvvigionamenti alimentari, il sostegno della filiera agroalimentare, della pesca e dell'acquacoltura, il coordinamento delle politiche di gestione delle risorse ittiche marine, la produzione di cibo di qualita', la cura e la valorizzazione delle aree e degli ambienti rurali, la promozione delle produzioni agroalimentari nazionali sui mercati internazionali.

3. Il ministero svolge in particolare, nei limiti stabiliti dal predetto articolo 2 dei decreto legislativo 4 giugno 1997, n. 143, le funzioni e i compiti nelle seguenti aree funzionali:

- a) agricoltura e pesca: elaborazione e coordinamento, di intesa con la conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e Bolzano, delle linee di politica agricola e forestale, in coerenza con quella comunitaria; trattazione, cura e rappresentanza degli interessi della pesca e acquacoltura nell'ambito della politica di mercato in sede comunitaria ed internazionale; disciplina generale e coordinamento delle politiche relative all'attivita' di pesca e acquacoltura, in materia di gestione delle risorse ittiche marine di interesse nazionale, di importazione e di esportazione dei prodotti ittici, nell'applicazione della regolamentazione comunitaria e di quella derivante dagli accordi internazionali e l'esecuzione degli obblighi comunitari ed internazionali riferibili a livello statale; adempimenti relativi al Fondo Europeo di Orientamento e Garanzia in Agricoltura (FEOGA), sezioni garanzia e orientamento, a livello nazionale e comunitario, compresa la verifica della regolarita' delle operazioni relative al FEOGA, sezione garanzia; riconoscimento e vigilanza sugli organismi pagatori statali di cui al regolamento n. 1663/95 della Commissione del 7 luglio 1995;
- b) qualita' dei prodotti agricoli e dei servizi: riconoscimento degli organismi di controllo e certificazione per la qualita'; trasformazione e commercializzazione dei prodotti agricoli e agroalimentari come definiti dal paragrafo 1 dell'articolo 32 del trattato che istituisce la Comunita' europea, come modificato dal trattato di Amsterdam, di cui alla legge 16 giugno 1998, n. 209; tutela e valorizzazione della qualita' dei prodotti agricoli e ittici; agricoltura biologica; promozione e tutela della produzione ecocompatibile e delle attivita' agricole nelle aree protette; certificazione delle attivita' agricole e forestali ecocompatibili; elaborazione del codex alimentarius; valorizzazione economica dei prodotti agricoli, e ittici; riconoscimento e sostegno delle unioni e delle associazioni nazionali dei produttori agricoli; accordi interprofessionali di dimensione nazionale; prevenzione e repressione - attraverso l'ispettorato centrale repressione frodi di cui all'articolo 10 del decreto legge 18 giugno 1986, n. 282, convertito con modificazioni, dalla legge 7 agosto 1986, n. 462 - nella preparazione e nel commercio dei prodotti agroalimentari e ad uso agrario; controllo sulla qualita' delle merci di importazione, nonche' lotta alla concorrenza sleale.
- b-bis) LETTERA ABROGATA DAL D.L. 21 SETTEMBRE 2019, N. 104.

### Art. 34. - (Ordinamento)

1. Il ministero si articola in dipartimenti disciplinati ai sensi degli articoli 4 e 5 del presente decreto. Il numero dei dipartimenti non puo' essere superiore a ((tre)), in riferimento alle aree funzionali definite nel precedente articolo.

## ((MINISTERO DELL'AMBIENTE E DELLA SICUREZZA ENERGETICA))

### Art. 35. - (Attribuzioni)

1. COMMA ABROGATO DAL D.L. 11 NOVEMBRE 2022, N. 173, CONVERTITO CON MODIFICAZIONI DALLA L. 16 DICEMBRE 2022, N. 204.

2. Al Ministero dell'ambiente e della sicurezza energetica sono attribuite le funzioni e i compiti spettanti allo Stato relativi allo sviluppo sostenibile e alla sicurezza energetica, ferme restando le funzioni della Presidenza del Consiglio dei ministri, e alla tutela dell'ambiente, del territorio e dell'ecosistema, nelle seguenti materie:

- a) individuazione, conservazione e valorizzazione delle aree naturali protette, tutela della biodiversita' e della biosicurezza, della fauna e della flora, attuazione e gestione, fatte salve le competenze della Presidenza del Consiglio dei ministri, del Ministero dell'agricoltura, della sovranita' alimentare e delle foreste e del Ministero degli affari esteri e della cooperazione internazionale, della Convenzione di Washington sul commercio internazionale delle specie animali e vegetali in via di estinzione, ratificata ai sensi della legge 19 dicembre 1975, n. 874, e dei relativi regolamenti europei, della difesa del mare e dell'ambiente costiero e della comunicazione ambientale;
- b) definizione degli obiettivi e delle linee di politica energetica e mineraria nazionale e provvedimenti ad essi inerenti; individuazione e attuazione delle misure atte a garantire la sicurezza, la flessibilita' e la continuita' degli approvvigionamenti di energia ((e a promuovere l'impiego delle fonti rinnovabili)); autorizzazione di impianti di produzione di energia di competenza statale, compresi quelli da fonti rinnovabili, anche se ubicati in mare; rapporti con organizzazioni internazionali e rapporti con l'Unione europea nel settore dell'energia, ferme restando le competenze del Presidente del Consiglio dei ministri e del Ministero degli affari esteri e della cooperazione internazionale, compresi il recepimento e l'attuazione dei programmi e delle direttive sul mercato unico europeo in materia di energia, ferme restando le competenze del Presidente del Consiglio dei ministri e delle regioni e delle province autonome di Trento e di Bolzano; attuazione dei processi di liberalizzazione dei mercati energetici e promozione della concorrenza nei mercati dell'energia e tutela dell'economicita' e della sicurezza del sistema con garanzia di resilienza; individuazione e sviluppo delle reti nazionali di trasporto dell'energia elettrica e del gas naturale e definizione degli indirizzi per la loro gestione; politiche di ricerca, incentivazione e interventi nei settori dell'energia e delle miniere; ricerca e coltivazione di idrocarburi, riconversione, dismissione e chiusura mineraria delle infrastrutture di coltivazione di idrocarburi ubicate nella terraferma e in mare e ripristino in sicurezza dei siti; risorse geotermiche; normativa tecnica, area chimica, sicurezza mineraria, escluse le competenze in materia di servizio ispettivo per la sicurezza mineraria e di vigilanza sull'applicazione della legislazione attinente alla salute sui luoghi di lavoro, e servizi tecnici per l'energia; vigilanza su enti strumentali e collegamento con le societa' e gli istituti operanti nei settori dell'energia; gestione delle scorte energetiche nonche' predisposizione ed attuazione dei piani di emergenza energetica; sicurezza nucleare e disciplina dei sistemi di stoccaggio del combustibile irraggiato e dei rifiuti radioattivi; radioprotezione e radioattivita' ambientale; agro-energie; rilevazione, elaborazione, analisi e diffusione di dati statistici in materia energetica e mineraria, finalizzati alla programmazione energetica e mineraria;
- c) piani e misure in materia di combustibili alternativi e delle relative reti e strutture di distribuzione per la ricarica dei veicoli elettrici, qualita' dell'aria, politiche per il contrasto dei cambiamenti climatici e per la finanza climatica e sostenibile e il risparmio ambientale anche attraverso tecnologie per la riduzione delle emissioni dei gas ad effetto serra;
- d) pianificazione in materia di emissioni nei diversi settori dell'attivita' economica, ivi compreso quello dei trasporti;
- e) gestione, riuso e riciclo dei rifiuti ed economia circolare;
- f) tutela delle risorse idriche e relativa gestione, fatta salva la competenza del Ministero dell'agricoltura, della sovranita' alimentare e delle foreste;
- g) promozione di politiche di sviluppo sostenibile, nazionali e internazionali;
- h) promozione di politiche per l'economia circolare e l'uso efficiente delle risorse, fatte salve le competenze del Ministero delle imprese e del made in Italy;
- i) coordinamento delle misure di contrasto e contenimento del danno ambientale, nonche' di bonifica e di ripristino in sicurezza dei siti inquinati, ivi compresi i siti per i quali non e' individuato il responsabile della contaminazione e quelli per i quali i soggetti interessati non provvedono alla realizzazione degli interventi, nonche' esercizio delle relative azioni giurisdizionali;
- l) sorveglianza, monitoraggio e recupero delle condizioni ambientali conformi agli interessi fondamentali della collettivita' e alla riduzione dell'impatto delle attivita' umane sull'ambiente, con particolare riferimento alla prevenzione e repressione delle violazioni compiute in danno dell'ambiente; prevenzione e protezione dall'inquinamento atmosferico, acustico ed elettromagnetico e dai rischi industriali;
- m) difesa e assetto del territorio con riferimento ai valori naturali e ambientali.

3. Al ministero sono trasferite con le inerenti risorse, le funzioni e i compiti dei ministeri dell'ambiente e dei lavori pubblici, eccettuate quelle attribuite, anche dal presente decreto, ad altri ministeri o agenzie e fatte in ogni caso salve le funzioni conferite alle regioni e agli enti locali anche ai sensi e per gli effetti degli articoli 1, comma 2, e 3, comma 1, lettere a) e b) della legge 15 marzo 1997, n. 59; sono altresi' trasferite le funzioni e i compiti attribuiti al ministero delle politiche agricole in materia di polizia forestale ambientale.

### Art. 36.

(Poteri di indirizzo politico e di vigilanza del Ministro).

1. Al Ministro dell'ambiente e della tutela del territorio e' attribuita la titolarita' dei poteri di indirizzo politico, di cui agli articoli 4 e 14 del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, nonche' la titolarita' del potere di vigilanza con riferimento all'Agenzia per la protezione dell'ambiente e per i servizi tecnici (APAT), ai sensi degli articoli 8, comma 2, 38, comma 1, e dell'articolo 1 del decreto del Presidente della Repubblica 8 agosto 2002, n. 207, e all'Istituto centrale per la ricerca applicata al mare (ICRAM). Con successivo decreto ministeriale, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, si provvede a ridefinire i compiti e l'organizzazione dell'ICRAM.

(( 1-bis. Nei processi di elaborazione degli atti di programmazione del Governo aventi rilevanza ambientale e' garantita la partecipazione del Ministero dell'ambiente e della tutela del territorio))

### Art. 37. - (Ordinamento)

1. Il Ministero si articola in dipartimenti disciplinati ai sensi degli articoli 4 e 5 del presente decreto. Il numero dei dipartimenti ((non puo' essere superiore a tre)), in riferimento alle aree funzionali definite all'articolo 35 del presente decreto ((, e il numero delle direzioni generali non puo' essere superiore a dieci.))

2. Il ministero si avvale altresi' degli uffici territoriali del governo di cui all'articolo 11.

### Art. 38. - (Agenzia per la protezione dell'ambiente e per i servizi tecnici)

1. E' istituita l'agenzia per la protezione dell'ambiente e per i servizi tecnici nelle forme disciplinate dagli articoli 8 e 9.

2. L'agenzia svolge i compiti e le attivita' tecnico-scientifiche di interesse nazionale per la protezione dell'ambiente, per la tutela delle risorse idriche e della difesa del suolo, ivi compresi l'individuazione e delimitazione dei bacini idrografici nazionali e interregionali.

3. All'agenzia sono trasferite le attribuzioni dell'agenzia nazionale per la protezione dell'ambiente, quelle dei servizi tecnici nazionali istituiti presso la presidenza del consiglio dei ministri, ad eccezione di quelle del servizio sismico nazionale.

((

4. Lo statuto dell'Agenzia, emanato ai sensi dell'articolo 8, comma 4, prevede l'istituzione di un consiglio federale rappresentativo delle agenzie regionali per la protezione dell'ambiente, con funzioni consultive nei confronti del direttore generale e del comitato direttivo. Lo statuto prevede altresi' che il comitato direttivo sia composto di quattro membri, di cui due designati dal Ministero dell'ambiente e due designati dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. Lo statuto disciplina inoltre le funzioni e le competenze degli organismi sopra indicati e la loro durata, nell'ambito delle finalita' indicate dagli articoli 03, comma 5, e 1, comma 1, lettera b), del decreto-legge 4 dicembre 1993, n. 496, convertito, con modificazioni, dalla legge 21 gennaio 1994, n. 61.

))

5. Sono soppressi l'agenzia nazionale per la protezione dell'ambiente, i servizi tecnici nazionali istituiti presso la presidenza del consiglio dei ministri. Il relativo personale e le relative risorse sono assegnate all'agenzia.

### Art. 39. - (Funzioni dell'agenzia)

1. L'agenzia svolge in particolare, le funzioni concernenti:

- a) la protezione dell'ambiente, come definite dall'articolo 1 del decreto legge 4 dicembre 1993, n. 496, convertito dalla legge 21 gennaio 1994, n. 61, nonche' le altre assegnate all'agenzia medesima con decreto del ministro dell'ambiente e della tutela del territorio;
- b) il riassetto organizzativo e funzionale della difesa del suolo e delle acque di cui agli articoli 1 e 4 della legge 18 maggio 1989, n. 183, nonche' ogni altro compito e funzione di rilievo nazionale di cui all'articolo 88 del decreto legislativo 31 marzo 1998, n. 112 (( , ad eccezione dell'emanazione della normativa tecnica di cui all'articolo 88, comma 1, lettera v), del decreto legislativo 31 marzo 1998, n. 112, che rientra nell'esclusiva competenza del Registro italiano dighe - RID. ))

### Art. 40. - (Abrogazioni)

1. Sono abrogate le seguenti disposizioni:

- a) l'articolo 9, commi 1, 2, 3, 5, 6, 7, 8, 9, 10, 11, 12 e 13, della legge 18 maggio 1989, n. 183;
- b) l'articolo 1-ter, 2 e 2-ter del decreto legge 4 dicembre 1993, n. 496, convertito, con modificazioni, dalla legge 21 gennaio 1994,n. 61.

## MINISTERO DELLE INFRASTRUTTURE E DEI TRASPORTI

### Art. 41. - (Istituzione del ministero e attribuzioni)

1. E' istituito il ministero delle infrastrutture e dei trasporti.

2. Al ministero sono attribuite le funzioni e i compiti spettanti allo Stato in materia di identificazione delle linee fondamentali dell'assetto del territorio con riferimento alle reti infrastrutturali e al sistema delle citta' e delle aree metropolitane; reti infrastrutturali e opere di competenza statale; politiche urbane e dell'edilizia abitativa; opere marittime e infrastrutture idrauliche; trasporti e viabilita'.

3. Al ministero sono trasferite, con le inerenti risorse, le funzioni e i compiti dei ministeri dei lavori pubblici e dei trasporti e della navigazione, nonche' del dipartimento per le aree urbane istituito presso la presidenza del consiglio dei ministri, eccettuate quelle attribuite, anche dal presente decreto, ad altri ministeri o agenzie e fatte in ogni caso salve le funzioni conferite alle regioni e agli enti locali, anche ai sensi e per gli effetti degli articoli 1, comma 2, e 3, comma 1, lettere a) e b), della legge 15 marzo 1997, n. 59.

### Art. 42. - (Aree funzionali)

1. Il ministero svolge in particolare le funzioni e i compiti di spettanza statale nelle seguenti aree funzionali:

- a) programmazione, finanziamento, realizzazione e gestione delle reti infrastrutturali di interesse nazionale, ivi comprese le reti elettriche, idrauliche e acquedottistiche, e delle altre opere pubbliche di competenza dello Stato, ad eccezione di quelle in materia di difesa; qualificazione degli esecutori di lavori pubblici; costruzioni nelle zone sismiche (( . . . ));
- b) edilizia residenziale; aree urbane;
- c) navigazione e trasporto marittimo; vigilanza sui porti; demanio marittimo; sicurezza della navigazione e trasporto nelle acque interne; programmazione, previa intesa con le regioni interessate, del sistema idroviario padano-veneto; aviazione civile e trasporto aereo;
- d) trasporto terrestre, circolazione dei veicoli e sicurezza dei trasporti terrestri;
- d-bis) sicurezza e regolazione tecnica, salvo quanto disposto da leggi e regolamenti, concernenti le competenze disciplinate dall'articolo 41 e dal presente comma, ivi comprese le espropriazioni;
- d-ter) pianificazione delle reti, della logistica e dei nodi infrastrutturali di interesse nazionale, realizzazione delle opere corrispondenti e valutazione dei relativi interventi;
- d-quater) politiche dell'edilizia concernenti anche il sistema delle citta' e delle aree metropolitane.

2. Il ministero svolge, altresi', funzioni e compiti di monitoraggio, controllo e vigilanza nelle aree di cui al comma 1, nonche' funzioni di vigilanza sui gestori del trasporto derivanti dalla legge, dalla concessione e dai contratti di programma o di servizio, fatto salvo quanto previsto dal decreto legislativo 16 marzo 1999, n. 79.

### Art. 43. - (Ordinamento)

1. Il ministero si articola in dipartimenti, disciplinati ai sensi degli articoli 4 e 5. Il numero dei dipartimenti non puo' essere superiore a quattro, in relazione alle aree funzionali definite dal precedente articolo.

2. Il Ministero si articola in un numero non superiore a 16 direzioni generali e in uffici di funzioni dirigenziali di livello generale, alla cui individuazione e organizzazione si provvede ai sensi dell'articolo 4, nei limiti di posti di funzione individuati dalla pianta organica di cui al decreto del Presidente della Repubblica 26 marzo 2001, n. 177. La dotazione organica dei dirigenti di seconda fascia di cui alla tabella A allegata al citato decreto del Presidente della Repubblica n. 177 del 2001 e' ridotta di due unita'.

2-bis. Il Ministero si avvale delle Capitanerie di porto, alle quali non si applica il disposto dell'articolo 11.

2-ter. Sono istituiti a livello sovraregionale (( non piu' di )) dieci Servizi integrati infrastrutture e trasporti, di seguito denominati S.I.I.T., quali organi decentrati del Ministero delle infrastrutture e dei trasporti. Ogni S.I.I.T. e' articolato in due settori relativi, rispettivamente, all'area infrastrutture e all'area trasporti, a ciascuno dei quali e' preposto un dirigente generale, nominato ai sensi dell'articolo 19, comma 4, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni. Al S.I.I.T. competente per le regioni Lazio e Abruzzo e' preposto un dirigente generale nominato ai sensi dell'articolo 19, comma 3, del citato decreto legislativo n. 165 del 2001. I S.I.I.T. svolgono funzioni di carattere tecnico, amministrativo, operativo e gestionale nell'ambito delle competenze di cui agli articoli 41 e 42, comprese le corrispondenti attivita' di servizio.

2-quater. I S.I.I.T. possono promuovere e fornire, su base convenzionale, servizi di contenuto tecnico operativo e gestionale alle amministrazioni pubbliche, comprese quelle regionali e locali anche ad ordinamento autonomo, nonche' ai soggetti di cui alla legge 11 febbraio 1994, n. 109, e successive modificazioni e integrazioni, nel rispetto delle funzioni e dei compiti ad essi spettanti.

2-quinquies. Con decreto del Presidente della Repubblica, da emanare ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, n. 400, su proposta del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro per la funzione pubblica e il Ministro dell'economia e delle finanze, sentite le organizzazioni sindacali maggiormente rappresentative, si provvede alla struttura organizzativa e funzionale dei S.I.I.T. e alla loro articolazione territoriale, secondo il criterio dell'efficiente dimensionamento delle strutture e dei corrispondenti bacini di utenza, utilizzando prioritariamente il personale assegnato agli altri uffici, anche al fine di incrementare la qualita' delle funzioni e delle attivita' rese nei confronti dei singoli, delle imprese e delle pubbliche amministrazioni appartenenti agli enti territoriali.

2-sexies. Dalla data di entrata in vigore del regolamento di cui al comma 2-quinquies sono soppresse le strutture periferiche del Ministero dei trasporti e della navigazione e del Ministero dei lavori pubblici.

2-septies. Con uno o piu' decreti del Presidente della Repubblica, da emanare ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, n. 400, su proposta del Ministro delle infrastrutture e dei trasporti, sentite le organizzazioni sindacali maggiormente rappresentative, di concerto con il Ministro per la funzione pubblica e con il Ministro dell'economia e delle finanze, si provvede, nel rispetto delle disposizioni di cui al decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni:

- a) alla riorganizzazione del Ministero;
- b) al riordinamento del Consiglio superiore dei lavori pubblici quale organo di consulenza obbligatoria del Governo e organo di consulenza facoltativa per le regioni e gli altri enti pubblici competenti in materia di lavori pubblici.

### Art. 44. - (Agenzia dei trasporti terrestri e delle infrastrutture)

1. E' istituita l'agenzia dei trasporti terrestri e delle infrastrutture nelle forme disciplinate dagli articoli 8 e 9.

2. L'agenzia svolge le funzioni spettanti allo Stato in relazione:

- a) alla definizione degli standard e prescrizioni tecniche in materia di sicurezza dei trasporti terrestri;
- b) alla vigilanza ai fini della sicurezza dei trasporti ad impianto fisso, fatto salvo quanto stabilito dall'articolo 4, comma 1, lettera b), del decreto legislativo 19 novembre 1997, n. 422;
- c) alla omologazione e approvazione dei veicoli a motore e loro rimorchi, loro componenti e unita' tecniche indipendenti;
- d) alla vigilanza e al controllo tecnico in materia di revisioni generali e parziali sui veicoli a motore e i loro rimorchi, anche se svolte tramite officine autorizzate ai sensi della lettera d) del comma 3 dell'articolo 105 del decreto legislativo 31 marzo 1998, n. 112, nonche' in materia di visite e prove di veicoli in circolazione per trasporti nazionali e internazionali, anche con riferimento ai veicoli adibiti al trasporto di merci pericolose e deperibili;
- e) alla certificazione attribuita all'organismo notificato di cui all'articolo 20 della direttiva 96/48 CE del Consiglio del 23 luglio 1996, ed in generale alla certificazione in applicazione delle norme di base nell'ambito dei sistemi, sottosistemi, prodotti e processi relativi ai sistemi di trasporto;
- f) alla definizione di standard e prescrizioni tecniche in materia di sicurezza stradale e norme tecniche relative alle strade e loro pertinenze ed alla segnaletica stradale, ai sensi del decreto legislativo 30 aprile 1992, n. 285;
- g) ai collegamenti informatici e alle banche dati nazionali gestiti presso il centro elaborazione dati della motorizzazione civile.

3. Spetta altresi' all'agenzia il coordinamento dell'interoperabilita' dei sistemi di trasporto.

4. All'agenzia sono assegnate le competenze progettuali e gestionali in materia di infrastrutture di competenza statale, ivi comprese quelle esercitate dai provveditorati alle opere pubbliche e dagli uffici opere marittime.

5. Sono soppresse le strutture del ministero dei trasporti e della navigazione e del ministero dei lavori pubblici che svolgono le funzioni ed i compiti demandati all'agenzia, ai sensi dei precedenti commi. Il relativo personale e le relative risorse sono assegnate all'agenzia.

6. L'agenzia puo' articolarsi in strutture territoriali di livello regionale.

## ((IL MINISTERO DEL LAVORO E DELLE POLITICHE SOCIALI))

### Art. 45. - (Istituzione del ministero e attribuzioni)

1. E' istituito il Ministero del lavoro e delle politiche sociali.

2. Sono attribuite al Ministero le funzioni e i compiti spettanti allo Stato in materia di politiche sociali, con particolare riferimento alla prevenzione e riduzione delle condizioni di bisogno e disagio delle persone e delle famiglie, di politica del lavoro e sviluppo dell'occupazione, di tutela del lavoro e dell'adeguatezza del sistema previdenziale.

3. Al Ministero sono trasferite, con le inerenti risorse, le funzioni del Ministero del lavoro e della previdenza sociale, nonche' le funzioni del Dipartimento per gli affari sociali, operante presso la Presidenza del Consiglio dei Ministri, ivi compresa quelle in materia di immigrazione, eccettuate quelle attribuite, anche dal presente decreto, ad altri Ministeri o agenzie, e fatte in ogni caso salve, ai sensi e per gli effetti degli articoli 1, comma 2, e 3, comma 1, lettere a) e b), della legge 15 marzo 1997, n. 59, le funzioni conferite dalla vigente legislazione alle regioni e agli enti locali. Il Ministero esercita le funzioni di vigilanza sull'Agenzia per il servizio civile, di cui all'articolo 10, commi 7 e seguenti, del decreto legislativo 30 luglio 1999, n. 303. Il Ministero esercita altresi' le funzioni di vigilanza spettanti al Ministero del lavoro e della previdenza sociale, a norma dell'articolo 88, sull'Agenzia per la formazione e istruzione professionale.

4. Al ministero sono altresi' trasferite, con le inerenti risorse, le funzioni che, da parte di apposite strutture e con riferimento alle materie di cui al comma 1, sono esercitate: dal ((Ministero degli affari esteri e della cooperazione internazionale)), in materia di tutela previdenziale dei lavoratori emigrati; dal ministero dei trasporti e della navigazione, in materia di vigilanza sul trattamento giuridico, economico, previdenziale ed assistenziale del personale delle aziende autoferrotranviarie e delle gestioni governative, nonche' in materia di organizzazione, assistenza e previdenza del lavoro marittimo, portuale e della pesca; dallo stesso ministero dei trasporti e della navigazione in materia di previdenza e assistenza dei lavoratori addetti ai servizi di trasporto aereo; dal ministero dell'industria, del commercio e dell'artigianato, in materia di servizio ispettivo per la sicurezza mineraria e di vigilanza sull'applicazione della legislazione attinente alla salute sui luoghi di lavoro; dal ministero dell'interno, iniziative di cooperazione internazionale e attivita' di prevenzione e studio sulle emergenze sociali. PERIODO ABROGATO DAL D.LGS. 29 ottobre 1999, n. 419.

### Art. 46. - (Aree funzionali)

1. Il Ministero, in particolare, svolge le funzioni e i compiti di spettanza statale nelle seguenti aree funzionali:

- a) politiche sociali, di inclusione, coesione e protezione sociale; terzo settore; politiche per i flussi migratori per motivi di lavoro e politiche per l'inclusione dei cittadini stranieri; coordinamento e raccordo con gli organismi europei e internazionali, nelle materie di competenza;
- b) politiche del lavoro e per l'occupazione, anche in ottica di genere; servizi per il lavoro; regolazione dei rapporti di lavoro e tutela dei lavoratori; tutela della salute e della sicurezza nei luoghi di lavoro; mediazione per la soluzione di controversie collettive di lavoro; rappresentativita' sindacale; politiche previdenziali e assicurative; coordinamento e raccordo con gli organismi europei e internazionali, nelle materie di competenza;
- c) amministrazione generale; servizi comuni e indivisibili; affari generali e attivita' di gestione del personale; programmazione generale del fabbisogno del Ministero e coordinamento delle attivita' in materia di reclutamento del personale; rappresentanza della parte pubblica nei rapporti sindacali; tenuta e gestione di banche dati, delle piattaforme e dei sistemi informatici; acquisti centralizzati e gestione logistica; coordinamento della comunicazione istituzionale; attivita' di analisi, ricerca e studio sulle attivita' di competenza del Ministero; coordinamento e raccordo con gli organismi europei e internazionali, nelle materie di competenza.

2. Il Ministero svolge, altresi', i compiti di vigilanza su enti e attivita' previsti dalla legislazione vigente e assicura il coordinamento e la gestione delle risorse e programmi a valere sul bilancio ((dell'Unione europea)) o a questo complementari.

### Art. 47. - (Ordinamento)

1. Il Ministero si articola in dipartimenti, disciplinati ai sensi degli articoli 4 e 5. Il numero dei dipartimenti non puo' essere superiore a tre, in riferimento alle aree funzionali di cui all'articolo 46, e il numero delle posizioni di livello dirigenziale generale non puo' essere superiore a quindici, ivi ((compresi)) i capi dei dipartimenti. All'individuazione e all'organizzazione dei dipartimenti e delle direzioni generali si provvede sentite le organizzazioni sindacali maggiormente rappresentative.

2. COMMA ABROGATO DAL D.LGS. 21 GENNAIO 2004, N. 29.

3. Presso il ministero continua ad operare il comitato nazionale delle pari opportunita' di cui all'articolo 5 della legge 10 aprile 1991, n. 125.

## MINISTERO DELLA SALUTE))

### Art. 47-bis.

(Istituzione del Ministero e attribuzioni).

1. E' istituito il Ministero della salute.

2. Nell'ambito e con finalita' di salvaguardia e di gestione integrata dei servizi socio-sanitari e della tutela dei diritti alla dignita' della persona umana e alla salute, sono attribuite al Ministero le funzioni spettanti allo Stato in materia di tutela della salute umana, di coordinamento del Sistema sanitario nazionale, di concerto con il Ministero dell'economia e delle finanze per tutti i profili di carattere finanziario, di sanita' veterinaria, di tutela della salute nei luoghi di lavoro, di igiene e sicurezza degli alimenti, di contrasto ((di ogni emergenza)) sanitaria, nonche' ogni iniziativa volta alla cura delle patologie ((epidemico-pandemiche)) emergenti.

3. Al Ministero sono trasferite, con inerenti risorse, le funzioni del Ministero della sanita'. Il Ministero, con modalita' definite d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, esercita la vigilanza sull'Agenzia per i servizi sanitari regionali di cui al decreto legislativo 31 marzo 1998, n. 115.

### Art. 47-ter.

(Aree funzionali).

1. Il Ministero, in particolare, svolge le funzioni di spettanza statale nelle seguenti aree funzionali:

- a) ordinamento sanitario: indirizzi generali e coordinamento in materia di prevenzione, diagnosi, cura e riabilitazione delle malattie umane, ivi comprese le malattie infettive e diffusive; prevenzione, diagnosi e cura delle affezioni animali, ivi comprese le malattie infettive e diffusive e le zoonosi; ((programmazione tecnico-sanitaria di rilievo nazionale e indirizzo, coordinamento e monitoraggio delle attivita' tecniche sanitarie regionali, di concerto con il Ministero dell'economia e delle finanze per tutti i profili attinenti al concorso dello Stato al finanziamento del Servizio sanitario nazionale, anche quanto ai piani di rientro Regionali)); rapporti con le organizzazioni internazionali e l'Unione europea; ricerca scientifica in materia sanitaria;
- b) tutela della salute umana e sanita' veterinaria: tutela della salute umana anche sotto il profilo ambientale, controllo e vigilanza sui farmaci, sostanze e prodotti destinati all'impiego in medicina e sull'applicazione delle biotecnologie; adozione di norme, linee guida e prescrizioni tecniche di natura igienico-sanitaria, relative anche a prodotti alimentari; ((organizzazione dei servizi sanitari, professioni sanitarie, concorsi e stato giuridico del personale del Servizio sanitario nazionale, di concerto con il Ministero dell'economia e delle finanze per tutti i profili di carattere finanziario)); polizia veterinaria; tutela della salute nei luoghi di lavoro.

### Art. 47-quater.

(Ordinamento). ((

1. Il Ministero si articola in quattro dipartimenti, disciplinati ai sensi degli articoli 4 e 5. Il numero degli "uffici dirigenziali generali e' pari a 12)).

2. COMMA ABROGATO DAL D.LGS. 21 GENNAIO 2004, N. 29.

### Art. 48.

ARTICOLO ABROGATO DAL D.LGS. 29 OTTOBRE 1999, N. 419 ((4))

--------------- AGGIORNAMENTO (4) Il D.L. 12 giugno 2001, n. 217, convertito con modificazioni, dalla L. 3 agosto 2001, n. 317, ha disposto (con l'art. 11, comma 1) l'introduzione del Capo X-bis "Ministero della salute" dopo il capo X del titolo IV (comprendente gli artt. da 47-bis a 47-quater).

## ((MINISTERO DELL'ISTRUZIONE E DEL MERITO))

### Art. 49. - (( (Attribuzioni) ))

1. ((Al Ministero dell'istruzione e del merito)) sono attribuite le funzioni e i compiti spettanti allo Stato in ordine al sistema educativo di istruzione e formazione di cui all'articolo 2 della legge 28 marzo 2003, n. 53, e di cui all'articolo 13, comma 1, del decreto-legge 31 gennaio 2007, n. 7, convertito, con modificazioni, dalla legge 2 aprile 2007, n. 40.

2. Al Ministero sono trasferite, con le inerenti risorse finanziarie, strumentali e di personale, ivi compresa la gestione dei residui, le funzioni del Ministero dell'istruzione, dell'universita' e della ricerca, nei limiti di cui all'articolo 50, eccettuate quelle attribuite ad altri ministeri o ad agenzie, e fatte in ogni caso salve le funzioni conferite dalla vigente legislazione alle regioni ed agli enti locali. E' fatta altresi' salva l'autonomia delle istituzioni scolastiche, nel quadro di cui all'articolo 21 della legge 15 marzo 1997, n. 59.

### Art. 50. - (Aree funzionali)

1. Il Ministero, in particolare, svolge le funzioni di spettanza statale nelle seguenti aree funzionali: organizzazione generale dell'istruzione scolastica, ordinamenti e programmi scolastici, stato giuridico del personale, inclusa la definizione dei percorsi di abilitazione e specializzazione del personale docente e dei relativi titoli di accesso, sentito il Ministero dell'universita' e della ricerca; definizione dei criteri e dei parametri per l'organizzazione della rete scolastica; definizione degli obiettivi formativi nei diversi gradi e tipologie di istruzione; definizione degli indirizzi per l'organizzazione dei servizi del sistema educativo di istruzione e di formazione nel territorio al fine di garantire livelli di prestazioni uniformi su tutto il territorio nazionale; promozione del merito e valutazione dell'efficienza nell'erogazione dei servizi medesimi nel territorio nazionale; definizione dei criteri e parametri per l'attuazione di politiche sociali nella scuola; definizione di interventi a sostegno delle aree depresse per il riequilibrio territoriale della qualita' del servizio scolastico ed educativo; attivita' connesse alla sicurezza nelle scuole e all'edilizia scolastica, in raccordo con le competenze delle regioni e degli enti locali; formazione dei dirigenti scolastici, del personale docente, educativo e del personale amministrativo, tecnico e ausiliario della scuola; assetto complessivo e indirizzi per la valutazione del sistema educativo di istruzione e formazione, nonche' del sistema di istruzione tecnica superiore; congiuntamente con il Ministero dell'universita' e della ricerca, funzioni di indirizzo e vigilanza dell'Istituto nazionale per la valutazione del sistema educativo di istruzione e di formazione (INVALSI) e dell'Istituto nazionale di documentazione, innovazione e ricerca educativa (INDIRE), ((individuato)), senza nuovi o maggiori oneri per la finanza pubblica, anche come Agenzia nazionale per la gestione del programma europeo per l'istruzione, la formazione, la gioventu' e lo sport (Erasmus+) con riferimento alle misure di competenza del Ministero dell'istruzione e del merito, fermo restando che la nomina dei relativi presidenti e componenti dei consigli di amministrazione di cui all'articolo 11 del decreto legislativo 31 dicembre 2009, n. 213, e' effettuata con decreto del Ministro dell'istruzione e del merito; promozione dell'internazionalizzazione del sistema educativo di istruzione e formazione; sistema della formazione italiana nel mondo ferme restando le competenze del Ministero degli affari esteri e della cooperazione internazionale stabilite dal decreto legislativo 13 aprile 2017, n. 64 ; determinazione e assegnazione delle risorse finanziarie a carico del bilancio dello Stato e del personale alle istituzioni scolastiche autonome; ricerca e sperimentazione delle innovazioni funzionali alle esigenze formative; supporto alla realizzazione di esperienze formative finalizzate alla valorizzazione del merito e all'incremento delle opportunita' di lavoro e delle capacita' di orientamento degli studenti; valorizzazione della filiera formativa professionalizzante, inclusa l'istruzione tecnica superiore; riconoscimento dei titoli di studio e delle certificazioni in ambito europeo e internazionale e attivazione di politiche dell'educazione comuni ai paesi dell'Unione europea; consulenza e supporto all'attivita' delle istituzioni scolastiche autonome; programmi operativi nazionali nel settore dell'istruzione finanziati dall'Unione europea; istituzioni di cui all'articolo 137, comma 2, del decreto legislativo 31 marzo 1998, n. 112; altre competenze assegnate dalla legge 13 luglio 2015, n. 107, nonche' dalla vigente legislazione, ivi comprese le attivita' di promozione e coordinamento del sistema integrato dei servizi di educazione e di istruzione per bambini fino ai sei anni.

### Art. 51. - (Ordinamento)

1. Il Ministero si articola in due dipartimenti in relazione alle aree funzionali di cui all'articolo 50, disciplinati ai sensi degli articoli 4 e 5. Il numero di posizioni di livello dirigenziale generale non puo' essere superiore a ((ventotto)), ivi inclusi i capi dei dipartimenti.

## Ministero dell'universita' e della ricerca))

### Art. 51-bis. - (Istituzione del ministero e attribuzioni)

1. E' istituito il Ministero dell'universita' e della ricerca, cui sono attribuite le funzioni e i compiti spettanti allo Stato in materia di istruzione universitaria, di ((ricerca scientifica, tecnologica e artistica)) e di alta formazione artistica musicale e coreutica.

2. Al Ministero sono trasferite, con le inerenti risorse finanziarie, strumentali e di personale, ivi compresa la gestione dei residui, le funzioni del Ministero dell'istruzione, dell'universita' e della ricerca, nei limiti di cui all'articolo 51-ter, eccettuate quelle attribuite, ad altri ministeri o ad agenzie, ivi inclusa l'Agenzia nazionale per la ricerca (ANR) di cui all'articolo 1, comma 241, della legge 27 dicembre 2019, n. 160, e fatte in ogni caso salve, le funzioni conferite dalla vigente legislazione alle regioni ed agli enti locali. E' fatta altresi' salva l'autonomia delle istituzioni universitarie, degli enti di ricerca e delle istituzioni di alta formazione artistica musicale e coreutica.

### Art. 51-ter. - (Aree funzionali)

1. Il Ministero, in particolare, svolge le funzioni di spettanza statale nelle seguenti aree funzionali:compiti di indirizzo, programmazione e coordinamento della ricerca scientifica e tecnologica nazionale, dell'istruzione universitaria, dell'alta formazione artistica, musicale e coreutica e di ogni altra istituzione appartenente al sistema dell'istruzione superiore ad eccezione degli istituti tecnici superiori; programmazione degli interventi, indirizzo e coordinamento, normazione generale e finanziamento delle universita', delle istituzioni dell'alta formazione artistica, musicale e coreutica (AFAM) e degli enti di ricerca non strumentali; valorizzazione del merito e diritto allo studio; accreditamento e valutazione in materia universitaria e di alta formazione artistica, musicale e coreutica; attuazione delle norme europee e internazionali in materia di istruzione universitaria e alta formazione artistica musicale e coreutica, armonizzazione europea e integrazione internazionale del sistema universitario e di alta formazione artistica musicale e coreutica anche in attuazione degli accordi culturali stipulati a cura del Ministero degli affari esteri e della cooperazione internazionale; coordinamento e vigilanza degli enti e istituzioni di ricerca non strumentali; completamento dell'autonomia universitaria e dell'alta formazione artistica, musicale e coreutica; formazione di grado universitario e di alta formazione artistica e musicale; razionalizzazione delle condizioni d'accesso all'istruzione universitaria e accademica; partecipazione alle attivita' relative all'accesso alle amministrazioni e alle professioni, al raccordo tra istruzione universitaria, istruzione scolastica e formazione; valorizzazione e sostegno della ricerca libera nelle universita' e negli enti di ricerca nonche' nelle istituzioni dell'alta formazione artistica, musicale e coreutica; integrazione tra ricerca applicata e ricerca pubblica; coordinamento della partecipazione italiana a programmi nazionali e internazionali di ricerca; sostegno della ricerca spaziale e aerospaziale; cura dei rapporti con l'Agenzia nazionale di valutazione del sistema universitario e della ricerca (ANVUR); congiuntamente con il Ministero dell'istruzione e del merito, funzioni di indirizzo e vigilanza dell'Istituto nazionale per la valutazione del sistema educativo di istruzione e di formazione (INVALSI) e dell'Istituto nazionale di documentazione, innovazione e ricerca educativa (INDIRE), ((individuato)), senza nuovi o maggiori oneri per la finanza pubblica, anche come Agenzia nazionale per la gestione del programma europeo per l'istruzione, la formazione, la gioventu' e lo sport (Erasmus+) con riferimento alle misure di competenza del Ministero dell'universita' e della ricerca; cooperazione scientifica in ambito nazionale, europeo e internazionale; promozione e sostegno della ricerca delle imprese ivi compresa la gestione di apposito fondo per le agevolazioni anche con riferimento alle aree depresse e all'integrazione con la ricerca pubblica; finanziamento delle infrastrutture di ricerca anche nella loro configurazione di European Research Infrastructure Consortium (ERIC) di cui al regolamento (CE) n. 723/2009 del Consiglio del 25 giugno 2009; programmi operativi nazionali finanziati dall'Unione europea; finanziamento degli enti privati di ricerca e delle attivita' per la diffusione della cultura scientifica e artistica; supporto alle attivita' degli Osservatori, nazionale e regionali, per la formazione sanitaria specialistica di cui agli articoli 43 e 44 del decreto legislativo 17 agosto 1999, n. 368, nonche' alle attivita' dell'Osservatorio nazionale per le professioni sanitarie di cui all'articolo 10 del decreto del Ministro dell'istruzione, dell'universita' e della ricerca 19 febbraio 2009, pubblicato nella Gazzetta Ufficiale n. 119 del 25 maggio 2009; promozione del coordinamento delle attivita' di ricerca delle universita', degli enti pubblici di ricerca e delle istituzioni dell'alta formazione artistica, musicale e coreutica, perseguendo obiettivi di eccellenza e incrementando la sinergia e la cooperazione tra di essi e con il sistema economico-produttivo, pubblico e privato, nonche' valutazione dei progetti di ricerca; altre competenze assegnate dalla vigente legislazione.

### Art. 51-quater. - (Ordinamento)

1. Il Ministero si articola in uffici dirigenziali generali, coordinati da un segretario generale ai sensi degli articoli 4 e 6. Il numero degli uffici dirigenziali generali, incluso il segretario generale, e' pari a ((nove)), in relazione alle aree funzionali di cui all'articolo 51-ter.

## ((MINISTERO DELLA CULTURA))

### Art. 52. - (Attribuzioni)

1. Il ministero della cultura esercita, anche in base alle norme del decreto legislativo 20 ottobre 1998, n. 368, e del testo unico approvato con decreto legislativo 29 ottobre 1999, n. 490, le attribuzioni spettanti allo Stato in materia di beni culturali ((materiali e immateriali)), beni paesaggistici, spettacolo, cinema e audiovisivo, eccettuate quelle attribuite, anche dal presente decreto, ad altri ministeri o ad agenzie, e fatte in ogni caso salve, ai sensi e per gli effetti degli articoli 1, comma 2, e 3, comma 1, lettere a) e b), della legge 15 marzo 1997, n. 59, le funzioni conferite dalla vigente legislazione alle regioni ed agli enti locali.

2. Al ministero sono altresi' trasferite, con le inerenti risorse, le funzioni esercitate dal dipartimento per l'informazione e l'editoria, istituito presso la presidenza del consiglio dei ministri, in materia di diritto d'autore e disciplina della proprieta' letteraria e promozione delle attivita' culturali.

### Art. 53. - (Aree funzionali)

1. Il Ministero, in particolare, svolge le funzioni e i compiti di spettanza dello Stato nelle seguenti aree funzionali:

- a) tutela dei beni culturali e paesaggistici;
- b) gestione e valorizzazione ((, anche economica, del patrimonio culturale materiale e immateriale)), degli istituti e dei luoghi della cultura;
- c) promozione dello spettacolo, delle attivita' cinematografiche, teatrali, musicali, di danza, circensi, dello spettacolo viaggiante; promozione delle produzioni cinematografiche, audiovisive, radiotelevisive e multimediali;
- d) promozione delle attivita' culturali; sostegno all'attivita' di associazioni, fondazioni, accademie e altre istituzioni di cultura;
- e) studio, ricerca, innovazione ed alta formazione nelle materie di competenza;
- f) promozione del libro e sviluppo dei servizi bibliografici e bibliotecari nazionali; tutela del patrimonio bibliografico; gestione e valorizzazione delle biblioteche nazionali;
- g) tutela del patrimonio archivistico; gestione e valorizzazione degli archivi statali;
- h) diritto d'autore e disciplina della proprieta' letteraria;
- i) promozione delle imprese culturali e creative, della creativita' contemporanea, della cultura urbanistica e architettonica e partecipazione alla progettazione di opere destinate ad attivita' culturali;
- i-bis) vigilanza sull'Istituto per il credito sportivo e culturale Spa, per quanto di competenza.

### Art. 54.

(Ordinamento). ((

1. Il Ministero si articola in dipartimenti, disciplinati ai sensi degli articoli 4 e 5. Il numero dei dipartimenti non puo' essere superiore a quattro, in riferimento alle aree funzionali di cui all'articolo 53, e il numero delle posizioni di livello dirigenziale generale non puo' essere superiore a trentadue, ivi inclusi i capi dei dipartimenti.

2. L'individuazione e l'ordinamento degli uffici del Ministero sono stabiliti ai sensi dell'articolo 4. (31)

2-bis. A seguito del verificarsi di eventi calamitosi di cui all'articolo 2, comma 1, lettera c), della legge 24 febbraio 1992, n. 225, per i quali sia vigente o sia stato deliberato nei dieci anni antecedenti lo stato d'emergenza, il Ministro, con proprio decreto, puo', in via temporanea e comunque per un periodo non superiore a cinque anni, riorganizzare gli uffici del Ministero esistenti nelle aree colpite dall'evento calamitoso, ferma rimanendo la dotazione organica complessiva e senza nuovi o maggiori oneri per la finanza pubblica.(49)

--------------- AGGIORNAMENTO (31) Il D.L. 3 ottobre 2006, n. 262, convertito con modificazioni dalla L. 24 novembre 2006, n. 286, ha disposto (con l'art. 2, comma 95) che "Fino all'adozione del nuovo regolamento di organizzazione restano comunque in vigore le disposizioni del regolamento di cui al decreto del Presidente della Repubblica 10 giugno 2004, n. 173, in quanto compatibili con l'articolazione del Ministero". -------------- AGGIORNAMENTO (49) Il D.Lgs. 2 gennaio 2018, n. 1 ha disposto (con l'art. 47, comma 1, lettera t)) che "Tutti i riferimenti alla legge 24 febbraio 1992, n. 225 e ai relativi articoli, contenuti in altre disposizioni, si intendono riferiti al presente decreto e ai corrispondenti articoli. In particolare: [...] t) l'articolo 2 della legge n. 225 del 1992, citato nell'articolo 54, comma 2-bis, del decreto legislativo 30 luglio 1999, n. 300, deve intendersi riferito all'articolo 7 del presente decreto".

## MINISTERO DEL TURISMO))

### Art. 54-bis. - (Istituzione del Ministero e attribuzioni)

1. E' istituito il Ministero del turismo, cui ((sono attribuiti)) le funzioni e i compiti spettanti allo Stato in materia di turismo, ((eccettuati quelli attribuiti)), anche dal presente decreto, ad altri ministeri o ad agenzie, e fatte salve in ogni caso le funzioni conferite dalla vigente legislazione alle regioni e agli enti locali.

2. Al Ministero del turismo sono trasferite le funzioni esercitate dal Ministero per i beni e le attivita' culturali e per il turismo in materia di turismo.

### Art. 54-ter. - (Aree funzionali)

1. Il Ministero cura la programmazione, il coordinamento e la promozione delle politiche turistiche nazionali, i rapporti con le regioni e i progetti di sviluppo del settore turistico, le relazioni con l'Unione europea e internazionali in materia di turismo, fatte salve le competenze del Ministero degli affari esteri e della cooperazione internazionale; esso cura altresi' i rapporti con le associazioni di categoria e le imprese turistiche e con le associazioni dei consumatori.

((1-bis. Il Ministero ha la titolarita' del portale 'Italia.it', di cui al comma 2 dell'articolo 16 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, dei diritti connessi al dominio stesso e della relativa piattaforma tecnologica, al fine di coordinare e indirizzare strategicamente la strutturazione del portale medesimo e le attivita' di promozione delle politiche turistiche nazionali svolte per mezzo di esso))

### Art. 54-quater. - (Ordinamento)

1. Il Ministero si articola in uffici dirigenziali generali, coordinati da un segretario generale ai sensi degli articoli 4 e 6. Il numero degli uffici dirigenziali generali, incluso il segretario generale, ((e' pari a 7)).

## DISPOSIZIONI FINALI E TRANSITORIE CAPO I PROCEDURA DI ATTUAZIONE ED ENTRATA IN VIGORE

### Art. 55. - (Procedura di attuazione ed entrata in vigore)

1. A decorrere dalla data del decreto di nomina del primo governo costituito a seguito delle prime elezioni politiche successive all'entrata in vigore del presente decreto legislativo e salvo che non sia diversamente disposto dalle norme del presente decreto:

- a) sono istituiti: - il ministero dell'economia e delle finanze, - il ministero delle attivita' produttive, - il ministero dell'ambiente e della tutela del territorio, - il ministero delle infrastrutture e dei trasporti - il ministero del lavoro e delle politiche sociali, - il ministero dell'istruzione, dell'universita' e della ricerca. - il Ministero della salute.
- b) sono soppressi: - il ministero del tesoro, del bilancio e della programmazione economica, - il ministero delle finanze, - il ministero dell'industria, del commercio e dell'artigianato, - il ministero del commercio con l'estero, - il dipartimento per il turismo della presidenza del Consiglio dei ministri, - il ministero dell'ambiente, - il ministero dei lavori pubblici, - il ministero dei trasporti e della navigazione, - il dipartimento per le aree urbane della Presidenza del Consiglio dei Ministri, - il ministero del lavoro e della previdenza sociale, - il ministero della sanita', - il dipartimento per le politiche sociali della Presidenza del Consiglio dei ministri, - il ministero della pubblica istruzione, - il ministero dell'universita' e della ricerca scientifica e tecnologica.

2. Alla data di entrata in vigore del presente decreto legislativo il ministro e il ministero di grazia e giustizia assumono rispettivamente la denominazione di ministro della giustizia e ministero della giustizia e il ministro e il ministero per le politiche agricole assumono rispettivamente la denominazione di ministro delle politiche agricole e forestali e ministero delle politiche agricole e forestali.

3. Sino all'attuazione del comma 1, con regolamento adottato ai sensi del comma 4 bis dell'articolo 17 della legge 23 agosto 1988, n. 400, si puo' provvedere al riassetto dell'organizzazione dei singoli ministeri, in conformita' con la riorganizzazione del governo e secondo i criteri ed i principi previsti dal presente decreto legislativo.

4. Sono, comunque, fatti salvi i regolamenti di organizzazione gia' adottati ai sensi del comma 4-bis dell'articolo 17 della legge 23 agosto 1988, n. 400 e della legge 3 aprile 1997, n. 94.

5. Le disposizioni contenute all'articolo 11, commi 1, 2 e 3, trovano applicazione a decorrere dalla data indicata al comma 1.

6. Salvo disposizione contraria, la decorrenza dell'operativita' delle disposizioni del presente decreto e' distribuita, con decreto del Presidente del consiglio dei ministri, entro l'arco temporale intercorrente tra l'entrata in vigore del presente decreto e la data di cui al comma 1. Qualora ricorrano specifiche e motivate esigenze, il Presidente del Consiglio dei ministri, su proposta del Ministro competente, puo', con proprio decreto, differire o gradualizzare temporalmente singoli adempimenti od atti, relativi ai procedimenti di riorganizzazione dei Ministeri.

7. Al riordino del Magistrato delle acque di Venezia e del Magistrato per il Po si provvede, nel rispetto di quanto disposto dal decreto legislativo 31 marzo 1998, n. 112, con i decreti previsti dall'articolo 11, comma 3, della legge 15 marzo 1997, n.59.

8. A far data dal 1 gennaio 2000, le funzioni relative al settore agroindustriale esercitate dal ministero per le politiche agricole sono trasferite, con le inerenti risorse, al ministero dell'industria, del commercio e dell'artigianato. Per l'esercizio delle funzioni di cui agli articoli 35 e 36 del presente decreto legislativo il ministero dell'ambiente si avvale del Corpo forestale dello Stato. ((PERIODO SOPPRESSO DALLA L. 6 FEBBRAIO 2004, N. 36)).

9. All'articolo 46, comma 2, del decreto legislativo 3 febbraio 1993, n. 29, le parole "per le amministrazioni e le aziende autonome" sono sostituite dalle parole "per le amministrazioni, le agenzie e le aziende autonome".

### RIFORMA DEL MINISTERO DELLE FINANZE E DELL'AMMINISTRAZIONE FISCALE Sezione I (Ministero delle finanze)

#### Art. 56. - (Attribuzioni del ministero delle finanze)

1. Il ministero delle finanze svolge le seguenti funzioni statali:

- a) analisi, indagini e studi sulle politiche fiscali e sulla loro attuazione, ai fini della valutazione dei sistema tributario e delle scelte di settore in sede nazionale, comunitaria e internazionale;
- b) predisposizione dei relativi atti normativi, di programmazione e di indirizzo e cura dei rapporti interni ed internazionali per il conseguimento degli obiettivi fissati;
- c) indirizzo, vigilanza e controllo sui risultati di gestione delle agenzie fiscali, nel rispetto dell'autonomia gestionale ad esse attribuita; esercizio dei poteri di coordinamento e vigilanza attribuiti dalla legge su altri enti o organi che comunque esercitano funzioni in settori della fiscalita' di competenza dello Stato;
- d) coordinamento, secondo le modalita' previste dal presente decreto e salva la possibilita' di definire autonomamente forme di diretta collaborazione tra loro, delle attivita' e dei rapporti tra le agenzie fiscali e con gli altri enti e organi di cui alla lettera c);
- e) coordinamento, monitoraggio e controllo, anche attraverso apposite strutture per l'attuazione di strategie di integrazione tra i sistemi del ministero, delle agenzie e della guardia di finanza, del sistema informativo della fiscalita' e della rete unitaria di settore;
- f) comunicazione istituzionale con i contribuenti e con l'opinione pubblica per favorire la corretta applicazione della legislazione tributaria;
- g) amministrazione del personale e delle risorse necessarie allo svolgimento dei compiti del ministero e all'attivita' giurisdizionale delle commissioni tributarie.

2. Fermi restando l'articolo 1 della legge 23 aprile 1959, n. 189, l'autonomia organizzativa ed i compiti di polizia economica e finanziaria attribuiti al corpo della guardia di finanza, il coordinamento fra la guardia di finanza e le agenzie fiscali nelle attivita' operative inerenti alle funzioni trasferite alle agenzie stesse e' curato sulla base delle direttive impartite dal ministro delle finanze per realizzare la migliore collaborazione nella lotta all'evasione fiscale.

3. Nell'esercizio delle proprio funzioni il ministero favorisce ed attua la cooperazione con le regioni e gli enti locali ed il coordinamento con le loro attivita'.

#### Art. 57. - (Istituzione delle agenzie fiscali)

1. Per la gestione delle funzioni esercitate dai dipartimenti delle entrate, delle dogane, del territorio e di quelle connesse svolte da altri uffici del ministero sono istituite l'agenzia delle entrate, l'agenzia delle dogane ((e dei monopoli)) e l'agenzia del demanio, di seguito denominate agenzie fiscali. Alle agenzie fiscali sono trasferiti i relativi rapporti giuridici, poteri e competenze che vengono esercitate secondo la disciplina dell'organizzazione interna di ciascuna agenzia. ((42))

2. Le regioni e gli enti locali possono attribuire alle agenzie fiscali, in tutto o in parte, la gestione delle funzioni ad essi spettanti, regolando con autonome convenzioni le modalita' di svolgimento dei compiti e gli obblighi che ne conseguono.

-------------- AGGIORNAMENTO (42) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 23-quater, comma 10) che la presente modifica decorre dal 1° dicembre 2012.

#### Art. 58. - (Organizzazione del ministero)

1. Il ministero e' organizzato secondo i principi di distinzione tra direzione politica e gestione amministrativa.

2. Gli uffici nei quali si articola il ministero fanno capo ad un unico dipartimento.

3. L'organizzazione, la disciplina degli uffici e le dotazioni organiche del ministero sono stabilite con regolamento ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, n. 400.

#### Art. 59. - (Rapporti con le agenzie fiscali)

1. Il ministro delle finanze dopo l'approvazione da parte del Parlamento del documento di programmazione economica-finanziaria ed in coerenza con i vincoli e gli obiettivi stabiliti in tale documento, determina annualmente, e comunque entro il mese di settembre, con un proprio atto di indirizzo e per un periodo almeno triennale, gli sviluppi della politica fiscale, le linee generali e gli obiettivi della gestione tributaria, le grandezze finanziarie e le altre condizioni nelle quali si sviluppa l'attivita' delle agenzie fiscali. Il documento di indirizzo e' trasmesso al Parlamento.

2. Il ministro e ciascuna agenzia, sulla base del documento di indirizzo, stipulano una convenzione triennale, con adeguamento annuale per ciascun esercizio finanziario, con la quale vengono fissati:

- a) i servizi dovuti e gli obiettivi da raggiungere;
- b) le direttive generali sui criteri della gestione ed i vincoli da rispettare;
- c) le strategie per il miglioramento;
- d) le risorse disponibili;
- e) gli indicatori ed i parametri in base ai quali misurare l'andamento della gestione.

3. La convenzione prevede, inoltre:

- a) le modalita' di verifica dei risultati di gestione;
- b) le disposizioni necessarie per assicurare al ministero la conoscenza dei fattori gestionali interni all'agenzia, quali l'organizzazione, i processi e l'uso delle risorse. Le informazioni devono essere assunte in forma organizzata e sistematica ed esser tali da consentire una appropriata valutazione dell'attivita' svolta dall'agenzia;
- c) le modalita' di vigilanza sull'operato dell'agenzia sotto il profilo della trasparenza, dell'imparzialita' e della correttezza nell'applicazione delle norme, con particolare riguardo ai rapporti con i contribuenti.

4. Nella convenzione sono stabiliti, nei limiti delle risorse stanziate su tre capitoli che vanno a comporre una unita' previsionale di base per ciascuna agenzia, gli importi che vengono trasferiti, distinti per:

- a) gli oneri di gestione calcolati, per le diverse attivita' svolte dall'agenzia, sulla base di una efficiente conduzione aziendale e dei vincoli di servizio imposti per esigenze di carattere generale;
- b) le spese di investimento necessarie per realizza e i miglioramenti programmati;
- c) la quota incentivante connessa al raggiungimento degli obiettivi della gestione e graduata in modo da tenere conto del miglioramento dei risultati complessivi e del recupero di gettito nella lotta all'evasione effettivamente conseguiti.

5. Il ministero e le agenzie fiscali possono promuovere la costituzione o partecipare a societa' e consorzi che, secondo le disposizioni del codice civile, abbiano ad oggetto la prestazione di servizi strumentali all'esercizio delle funzioni pubbliche ad essi attribuite; a tal fine, puo' essere ampliato l'oggetto sociale della societa' costituita in base alle disposizioni dell'articolo 10, comma 12, della legge 8 maggio 1998, n.146, fermo restando che il ministero e le agenzie fiscali detengono la maggioranza delle azioni ordinarie della predetta societa'. ((48))

------------ AGGIORNAMENTO (48) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 1126) che "Al fine di garantire la continuita' operativa e gestionale necessaria per il conseguimento degli obiettivi strategici relativi alle attivita' informatiche riservate allo Stato ai sensi del decreto legislativo 19 novembre 1997, n. 414, e successivi provvedimenti di attuazione, gli istituti contrattuali che disciplinano il rapporto di servizio tra il Ministero dell'economia e delle finanze e la societa' di cui all'articolo 59 del decreto legislativo 30 luglio 1999, n. 300, sono prorogati fino al completamento delle procedure in corso per la stipula del nuovo atto regolativo".

#### Art. 60. - (Controlli sulle agenzie fiscali)

1. Le agenzie sono sottoposte all'alta vigilanza del ministro, il quale la esercita secondo le modalita' previste nel presente decreto legislativo.

(( 2. Le deliberazioni del comitato di gestione relative agli statuti, ai regolamenti e agli atti di carattere generale, individuati nella convenzione di cui all'articolo 59, che regolano il funzionamento delle agenzie sono trasmesse, per l'approvazione, al Ministro dell'economia e delle finanze. L'approvazione puo' essere negata per ragioni di legittimita' o di merito. Le deliberazioni si intendono approvate ove nei quarantacinque giorni dalla ricezione delle stesse non venga emanato alcun provvedimento ovvero non vengano chiesti chiarimenti o documentazione integrativa; in tale ultima ipotesi il termine per l'approvazione e' interrotto sino a che non pervengono gli elementi richiesti. Per l'approvazione dei bilanci e dei piani pluriennali di investimento si applicano le disposizioni del decreto del Presidente della Repubblica 9 novembre 1998, n. 439. Per l'Agenzia del demanio le disposizioni di cui ai primi tre periodi del presente comma si applicano con riferimento alle deliberazioni del comitato di gestione relative agli statuti, ai regolamenti ed ai bilanci))

3. Fermi i controlli sui risultati ((e quanto previsto dal comma 2)), gli altri atti di gestione delle agenzie non sono sottoposti a controllo ministeriale preventivo.

## Le agenzie fiscali

### Art. 61. - (Principi generali)

1. Le agenzie fiscali hanno personalita' giuridica di diritto pubblico. (( L'Agenzia del demanio e' ente pubblico economico. ))

2. In conformita' con le disposizioni del presente decreto legislativo e dei rispettivi statuti, le agenzie fiscali hanno autonomia regolamentare, amministrativa, patrimoniale, organizzativa, contabile e finanziaria.

3. Le agenzie fiscali operano nell'esercizio delle funzioni pubbliche ad esse affidate in base ai principi di legalita', imparzialita' e trasparenza, con criteri di efficienza, economicita' ed efficacia nel perseguimento delle rispettive missioni.

4. COMMA ABROGATO DALLA L. 24 NOVEMBRE 2000, N. 340.

### Art. 62. - (Agenzia delle entrate)

1. All'agenzia delle entrate sono attribuite tutte le funzioni concernenti le entrate tributarie erariali che non sono assegnate alla competenze di altre agenzie, amministrazioni dello Stato ad ordinamento autonomo, enti od organi, con il compito di perseguire il massimo livello di adempimento degli obblighi fiscali sia attraverso l'assistenza ai contribuenti, sia attraverso i controlli diretti a contrastare gli inadempimenti e l'evasione fiscale. L'agenzia delle entrate svolge, inoltre, le funzioni di cui all'articolo 64. (42)

2. L'agenzia e' competente in particolare a svolgere i servizi relativi alla amministrazione, alla riscossione e al contenzioso dei tributi diretti e dell'imposta sul valore aggiunto, nonche' di tutte le imposte, diritti o entrate erariali o locali, entrate anche di natura extratributaria, gia' di competenza del dipartimento delle entrate del ministero delle finanze o affidati alla sua gestione in base alla legge o ad apposite convenzioni stipulate con gli enti impositori o con gli enti creditori. ((Le funzioni e i compiti in materia di riscossione sono disciplinati dall'articolo 1 del decreto-legge 22 ottobre 2016, n. 193, convertito, con modificazioni, dalla legge 1° dicembre 2016, n. 225)).

3. In fase di prima applicazione il ministro delle finanze stabilisce con decreto i servizi da trasferire alla competenza dell'agenzia.

-------------- AGGIORNAMENTO (42) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 23-quater, comma 10) che la presente modifica decorre dal 1° dicembre 2012.

### Art. 63.

(Agenzia delle dogane ((e dei monopoli)) ) ((42))

1. L'agenzia delle dogane ((e dei monopoli)) e' competente a svolgere i servizi relativi all'amministrazione, alla riscossione e al contenzioso dei diritti doganali e della fiscalita' interna negli scambi internazionali, delle accise sulla produzione e sui consumi, escluse quelle sui tabacchi lavorati, operando in stretto collegamento con gli organi dell'Unione europea nel quadro dei processi di armonizzazione e di sviluppo dell'unificazione europea. All'agenzia spettano tutte le funzioni attualmente svolte dal dipartimento delle dogane ((e dei monopoli)) del ministero delle finanze, incluse quelle esercitate in base ai trattati dell'Unione europea o ad altri atti e convenzioni internazionali. ((L'agenzia svolge, inoltre, le funzioni gia' di competenza dell'Amministrazione autonoma dei Monopoli di Stato)). ((42))

2. L'agenzia gestisce con criteri imprenditoriali i laboratori doganali di analisi; puo' anche offrire sul mercato le relative prestazioni.

3. In fase di prima applicazione il ministro delle finanze stabilisce con decreto i servizi da trasferire alla competenza dell'agenzia.

-------------- AGGIORNAMENTO (42) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 23-quater, comma 10) che la presente modifica decorre dal 1° dicembre 2012.

### Art. 64. - (Ulteriori funzioni dell'agenzia delle entrate)

1. L'agenzia delle entrate e' inoltre competente a svolgere i servizi relativi al catasto, i servizi geotopocartografici e quelli relativi alle conservatorie dei registri immobiliari, con il compito di costituire l'anagrafe dei beni immobiliari esistenti sul territorio nazionale sviluppando, anche ai fini della semplificazione dei rapporti con gli utenti, l'integrazione fra i sistemi informativi attinenti alla funzione fiscale ed alle trascrizioni ed iscrizioni in materia di diritti sugli immobili. L'agenzia opera in stretta collaborazione con gli enti locali per favorire lo sviluppo di un sistema integrato di conoscenze sul territorio.

2. L'agenzia costituisce l'organismo tecnico di cui all'articolo 67 del decreto legislativo 31 marzo 1998 n.112 e puo' gestire, sulla base di apposite convenzioni stipulate con i comuni o, a livello provinciale con le associazioni degli enti locali, i servizi relativi alla tenuta e all'aggiornamento del catasto.

3. L'agenzia gestisce l'osservatorio del mercato immobiliare.

3-bis. Ferme le attivita' di valutazione immobiliare per le amministrazioni dello Stato di competenza dell'Agenzia del demanio, l'Agenzia ((delle entrate)) e' competente a svolgere le attivita' di valutazione immobiliare e tecnico-estimative richieste dalle amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e dagli enti ad esse strumentali. Le predette attivita' sono disciplinate mediante accordi, secondo quanto previsto dall'articolo 15 della legge 7 agosto 1990, n. 241, e successive modificazioni. Tali accordi prevedono il rimborso dei costi sostenuti dall'Agenzia, la cui determinazione e' stabilita nella Convenzione di cui all'articolo 59.

4. Il comitato di gestione di cui all'articolo 67 del presente decreto legislativo e' integrato, per l'agenzia ((delle entrate)), da due membri nominati su designazione della Conferenza Stato-citta' ed autonomie locali. ((43)) (42)

-------------- AGGIORNAMENTO (42) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 23-quater, comma 10) che la presente modifica decorre dal 1° dicembre 2012. -------------- AGGIORNAMENTO (43) Il D.L. 10 ottobre 2012, n. 174, convertito con modificazioni dalla L. 7 dicembre 2012, n. 213, ha disposto (con l'art. 9, comma 6-quater, lettera b)) che "Per esigenze di coordinamento, fermi la data e gli effetti delle incorporazioni previsti dall'articolo 23-quater del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135: a) [. . .] b) tenuto conto dell'incorporazione dell'Agenzia del territorio nell'Agenzia delle entrate, si intende che i due componenti di cui all'articolo 64, comma 4, del decreto legislativo 30 luglio 1999, n. 300, successivamente al 1° dicembre 2012 deliberano per le sole materie ivi indicate."

### Art. 65. - (Agenzia del demanio)

1. All'agenzia del demanio e' attribuita l'amministrazione dei beni immobili dello Stato, con il compito di razionalizzarne e valorizzarne l'impiego, di sviluppare il sistema informativo sui beni del demanio e del patrimonio, utilizzando in ogni caso, nella valutazione dei beni a fini conoscitivi ed operativi, criteri di mercato, di gestire con criteri imprenditoriali i programmi di vendita, di provvista, anche mediante l'acquisizione sul mercato, di utilizzo e di manutenzione ordinaria e straordinaria di tali immobili. All'agenzia e' altresi' attribuita la gestione dei beni confiscati. ((42))

2. L'agenzia puo' stipulare convenzioni per le gestioni dei beni immobiliari con le regioni gli enti locali ed altri enti pubblici. Puo' avvalersi, a supporto delle proprie attivita' estimative e sulla base di apposita convenzione, dei dati forniti dall'osservatorio del mercato immobiliare dell'agenzia del territorio.

2-bis. L'Agenzia del demanio e' dotata di un proprio patrimonio, costituito da un fondo di dotazione e dai beni mobili ed immobili strumentali alla sua attivita'. Con decreto del Ministro dell'economia e delle finanze sono individuati i beni che costituiscono il patrimonio iniziale.

--------------- AGGIORNAMENTO (42) Il D.L. 6 luglio 2012 n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 3, comma 18) che "All'articolo 65, comma 1, del decreto legislativo 30 luglio 1999, n. 300 e successive modifiche e integrazioni, le disposizioni di cui all'ultimo periodo sono da intendersi riferite alla gestione dei beni immobili, fatta salva la competenza, prevista da normativa speciale, di altri soggetti pubblici".

### Art. 66. - (Statuti)

1. Le agenzie fiscali sono regolate dal presente decreto legislativo, nonche' dai rispettivi statuti, deliberati da ciascun ((comitato di gestione)) ed approvati con le modalita' di cui all'articolo 60 dal ministro delle finanze. (( L'Agenzia del demanio e' regolata, salvo che non sia diversamente disposto dal presente decreto legislativo, dal codice civile e dalle altre leggi relative alle persone giuridiche private. ))

2. Gli statuti disciplinano le competenze degli organi di direzione dell'agenzia, istituendo inoltre apposite strutture di controllo interno, e recano principi generali in ordine alla organizzazione ed al funzionamento dell'agenzia, prevedendo forme adeguate di consultazione con le organizzazioni sindacali.

3. L'articolazione degli uffici, a livello centrale e periferico, e' stabilita con disposizioni interne che si conformano alle esigenze della conduzione aziendale favorendo il decentramento delle responsabilita' operative, la semplificazione dei rapporti con i cittadini e il soddisfacimento delle necessita' dei contribuenti meglio compatibile con i criteri di economicita' e di efficienza dei servizi

### Art. 67. - (Organi)

1. Sono organi delle agenzie fiscali:

- a) il direttore dell'agenzia, scelto in base a criteri di alta professionalita', di capacita' manageriale e di qualificata esperienza nell'esercizio di funzioni attinenti al settore operativo dell'agenzia;
- b) il comitato di gestione, composto da quattro membri e dal direttore dell'agenzia, che lo presiede;
- c) il collegio dei revisori dei conti.

2. Il direttore e' nominato con decreto del Presidente della Repubblica previa deliberazione del consiglio dei ministri, su proposta del ministro delle finanze, sentita la conferenza unificata Stato-regioni-autonomie locali. L'incarico ha la durata massima di tre anni, e' rinnovabile ed e' incompatibile con altri rapporti di lavoro subordinato e con qualsiasi altra attivita' professionale pubblica o privata. (13)

3. Il comitato di gestione e' nominato per la durata di tre anni con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro dell'economia e delle finanze. Meta' dei componenti sono scelti tra i dipendenti di pubbliche amministrazioni, ferma restando ai fini della scelta la legittimazione gia' riconosciuta a quelli rientranti nei settori di cui all'articolo 19, comma 6, terzo periodo, del decreto legislativo 30 marzo 2001, n. 165, ovvero tra soggetti ad esse esterni dotati di specifica competenza professionale attinente ai settori nei quali opera l'agenzia. I restanti componenti sono scelti tra i dirigenti dell'agenzia, ((anche)) in servizio, in ragione ((della competenza del comitato a svolgere anche funzioni di alta consulenza)) nei riguardi del direttore relativamente alle attribuzioni di competenza. (31)

4. Il collegio dei revisori dei conti e' composto dal presidente, da due membri effettivi e due supplenti iscritti al registro dei revisori contabili, nominati con decreto del ministro delle finanze di concerto con il ministro del tesoro, del bilancio e della programmazione economica. I revisori durano in carica tre anni e possono essere confermati una sola volta. Il collegio dei revisori dei conti esercita le funzioni di cui all'articolo 2403 del codice civile, in quanto applicabile.

5. I componenti del comitato di gestione non possono svolgere attivita' professionale, ne' essere amministratori o dipendenti di societa' o imprese, nei settori di intervento dell'agenzia.

6. I compensi dei componenti degli organi collegiali sono stabiliti con decreto del ministro delle finanze, di concerto con il ministro del tesoro, del bilancio e della programmazione economica e sono posti a carico del bilancio dell'agenzia. (13) ----------------- AGGIORNAMENTO (13) Il D.Lgs. 3 luglio 2003, n. 173 ha disposto (con l'art. 1, comma 1, lettera m)) che al comma 2 del presente articolo, sono soppresse le parole: "o pubblica". Ha inoltre disposto (con l'art. 3, comma 2) che in sede di prima applicazione del presente articolo, come modificato dal decreto legislativo 3 luglio 2003, n. 173, ferma restando l'applicabilita' ai direttori delle Agenzie fiscali dell'articolo 6, comma 2, della legge 24 luglio 2002, n. 145, il termine di durata triennale dell'incarico dei direttori e dei collegi dei revisori dei conti delle Agenzie decorre dalla data in cui le Agenzie sono state rese operative. I comitati direttivi delle Agenzie fiscali continuano ad operare sino alla costituzione dei comitati di gestione, da effettuare entro trenta giorni dalla data di entrata in vigore del suddetto decreto legislativo 3 luglio 2003, n. 173. ----------------- AGGIORNAMENTO (31) Il D.L. 3 ottobre 2006, n. 262, convertito con modificazioni dalla L. 24 novembre 2006, n. 286, ha disposto (con l'art. 1, comma 18) che in sede di prima applicazione della modifica di cui al comma 3 del presente articolo, i comitati di gestione delle agenzie fiscali in carica alla data di entrata in vigore del decreto legge 3 ottobre 2006, n. 262, cessano automaticamente il trentesimo giorno successivo.

### Art. 68. - (Funzioni)

1. Il direttore rappresenta l'agenzia e la dirige, emanando tutti i provvedimenti che non siano attribuiti, in base alle norme del presente decreto legislativo o dello statuto, ad altri organi.

2. Il ((comitato di gestione)) delibera, su proposta del presidente, lo statuto, i regolamenti e gli altri atti di carattere generale che regolano il funzionamento dell'agenzia, i bilanci preventivi e consuntivi, i piani aziendali e le spese che impegnino il bilancio dell'agenzia, anche se ripartite in piu' esercizi, per importi superiori al limite fissato dallo statuto. Il direttore sottopone alla valutazione del (( comitato di gestione )) le scelte strategiche aziendali e le nomine dei dirigenti responsabili delle strutture di vertice a livello centrale e periferico.

### Art. 69. - (Commissario straordinario)

1. Nei casi di gravi inosservanze degli obblighi sanciti nella convenzione, di risultati particolarmente negativi della gestione, di manifesta impossibilita' di funzionamento degli organi di vertice dell'agenzia o per altre gravi ragioni di interesse pubblico, con decreto dei presidente del consiglio dei ministri su proposta del ministro delle finanze puo' essere nominato un commissario straordinario, il quale assume i poteri, previsti dal presente decreto legislativo e dallo statuto di ciascuna agenzia, del direttore del (( comitato di gestione )) dell'agenzia. Per i compensi del commissario straordinario si applicano le disposizioni dell'articolo 67, comma 6.

2. La nomina e' disposta per il periodo di un anno e puo' essere prorogata per non oltre sei mesi. A conclusione dell'incarico del commissario sono nominati il direttore e il ((comitato di gestione)) subentranti.

### Art. 70. - (Bilancio e finanziamento)

1. Le entrate delle agenzie fiscali sono costituite da:

- a) i finanziamenti erogati in base alle disposizioni dell'articolo 59 del presente decreto legislativo a carico del bilancio dello Stato;
- b) i corrispettivi per i servizi prestati a soggetti pubblici o privati, incluse le amministrazioni statali per le prestazioni che non rientrano nella convenzione di cui all'articolo 59;
- c) altri proventi patrimoniali e di gestione.

(( 2. I finanziamenti di cui al comma 1, lettera a), vengono determinati in modo da tenere conto dell'incremento dei livelli di adempimento fiscale e del recupero di gettito nella lotta all'evasione. I finanziamenti vengono accreditati a ciascuna Agenzia su apposita contabilita' speciale soggetta ai vincoli del sistema di tesoreria unica))

3. Le agenzie, che possono stipulare convenzioni con aziende di credito per la gestione del servizio di tesoreria, non hanno facolta' di accendere mutui, ne' di adire ad alcuna forma di indebitamento, fatta eccezione per le anticipazioni di cassa previste nelle convenzioni per la gestione del servizio di tesoreria.

4. In sede di prima attuazione i finanziamenti di cui alla lettera a) del comma 1 sono determinati sulla base delle assegnazioni di bilancio iscritte nello stato di previsione del ministero delle finanze destinate all'espletamento delle funzioni trasferite a ciascuna agenzia.

5. Il comitato di gestione delibera il regolamento di contabilita', che e' sottoposto al ministro delle finanze secondo le disposizioni dell'articolo 60. Il regolamento si conforma, nel rispetto delle disposizioni generali in materia di contabilita' pubblica e anche prevedendo apposite note di raccordo della contabilita' aziendale, ai principi desumibili dagli articoli 2423 e seguenti del codice civile.

6. Le agenzie fiscali non possono impegnare o erogare spese eccedenti le entrate. I piani di investimento e gli impegni a carattere pluriennale devono conformarsi al limite costituito dalle risorse finanziarie stabilite dalla legge finanziaria e dalle altre entrate proprie delle agenzie fiscali.

### Art. 71. - (Personale)

1. Il rapporto di lavoro del personale dipendente delle agenzie fiscali e' disciplinato dalla contrattazione collettiva e dalle leggi che regolano il rapporto di lavoro privata, in conformita' delle norme del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni ed integrazioni, anche per quanto attiene alla definizione del comparto di contrattazione per le agenzie fiscali; ciascuna agenzia definisce la contrattazione integrativa aziendale di secondo livello.

2. Al fine di garantire l'imparzialita' e il buon andamento nell'esercizio della funzione pubblica assegnata alle agenzie fiscali, con regolamento da emanare entro sei mesi dall'entrata in vigore del presente decreto legislativo, ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono emanate disposizioni idonee a garantire l'indipendenza e l'autonomia tecnica del personale.

3. Il regolamento di amministrazione e' deliberato, su proposta del direttore dell'agenzia, dal ((comitato di gestione)) ed e' sottoposto al ministro vigilante secondo le disposizioni dell'articolo 60 del presente decreto legislativo. In particolare esso, in conformita' con i principi contenuti nel decreto legislativo 3 febbraio 1993, n.29, e successive modificazioni ed integrazioni:

- a) disciplina l'organizzazione e il funzionamento dell'agenzia;
- b) detta le norme per l'assunzione del personale dell'agenzia, per l'aggiornamento e per la formazione professionale;
- c) fissa le dotazioni organiche complessive del personale dipendente dall'agenzia;
- d) determina le regole per l'accesso alla dirigenza.

### Art. 72. - (Rappresentanza in giudizio)

l. Le agenzie fiscali possono avvalersi del patrocinio dell'Avvocatura dello Stato, ai sensi dell'articolo 43 del testo unico approvato con regio decreto 30 ottobre 1933, n. 1611, e successive modificazioni.

## Disposizioni transitorie

### Art. 73. - (Gestione e fasi del cambiamento)

1. Con decreto ministeriale puo' essere costituita, alle dirette dipendenze del ministro delle finanze, un'apposita struttura interdisciplinare di elevata qualificazione scientifica e professionale. La struttura collabora con il ministro al fine di curare la transizione durante le fasi del cambiamento e fino al pieno funzionamento del regime di gestione previsto dal presente decreto legislativo. Alle relative spese si provvede con gli stanziamenti ordinari dello stato di previsione della spesa del ministero delle finanze e dello stato di previsione della spesa dell'amministrazione autonoma dei monopoli di Stato. Quando vengono trattate questioni riguardanti le materie trattate dalle agenzie fiscali, alle riunioni della struttura di cui al presente comma partecipano, senza oneri a carico del bilancio dello Stato, i direttori delle agenzie interessate. ((31))

2. Il ministro delle finanze provvede con propri decreti a definire e rendere esecutive le fasi della trasformazione.

3. Entro il termine di sei mesi dalla data di entrata in vigore del presente decreto legislativo, vengono nominati il direttore e i comitati direttivi di ciascuna agenzia. Con propri decreti il ministro delle finanze approva gli statuti provvisori e le disposizioni necessarie al primo funzionamento di ciascuna agenzia.

4. Il ministro delle finanze stabilisce le date a decorrere dalle quali le funzioni svolte dal ministero, secondo l'ordinamento vigente, vengono esercitate dalle agenzie. Da tale data le funzioni cessano di essere esercitate dai dipartimenti del ministero.

5. Il ministro delle finanze dispone con decreto in ordine alle assegnazioni di beni e personale afferenti alle attivita' di ciascuna agenzia.

6. I termini di cui al presente articolo possono essere modificati con decreto del ministro delle finanze.

7. Con l'entrata in vigore del regolamento di cui all'articolo 58, comma 3, sono abrogate tutte le norme sulla organizzazione e sulla disciplina degli uffici dell'amministrazione finanziaria incompatibili con le disposizioni del presente decreto legislativo e, in particolare quelle del regio decreto-legge 8 dicembre 1927, n. 2258 e successive integrazioni e modifiche, del decreto legislativo 26 aprile 1990, n. 105 e successive integrazioni e modifiche, della legge 29 ottobre 1991, n. 358 e successive integrazioni e modifiche degli articoli, da 9 a 12 della legge 24 aprile 1980, n.146 e successive integrazioni e modifiche.

--------------- AGGIORNAMENTO (31) Il D.L. 3 ottobre 2006, n. 262, convertito con modificazioni dalla L. 24 novembre 2006, n. 286, ha disposto (con l'art. 1, comma 17) che al fine di ridurre gli oneri derivanti dal funzionamento degli organismi collegiali la struttura interdisciplinare prevista dal comma 1 del presente articolo, il comitato di coordinamento del Servizio consultivo ed ispettivo tributario, il Comitato di indirizzo strategico della Scuola superiore dell'economia e delle finanze nonche' la Commissione consultiva per la riscossione sono soppressi

### Art. 74. - (Disposizioni transitorie sul personale)

1. A partire dalla data fissata con decreto del ministro delle finanze, tutto il personale del ministero e' incluso in un ruolo speciale e distaccato presso i nuovi uffici del ministero o presso le agenzie fiscali secondo un piano diretto a consentire l'avvio delle attivita' in conformita' con le trasformazioni attuate con il presente decreto legislativo. Il piano si conforma, previa concertazione con le organizzazioni sindacali, a criteri di maggiore aderenza alle funzioni ed alle attivita' svolte in precedenza dai singoli dipendenti, inclusi quelli appartenenti ad uffici soppressi.

2. Il trattamento giuridico ed economico definito o da definire ai sensi del decreto legislativo 3 febbraio 1993, n. 29 e successive modificazioni ed integrazioni, continua ad applicarsi ai dipendenti di cui al comma 1 fino alla stipulazione dei nuovi contratti collettivi di lavoro, fermi altresi' gli istituti e le procedure che regolano le relazioni sindacali.

3. Ciascun dirigente svolge il proprio incarico, fino alla scadenza del relativo termine e secondo le modalita' del contratto individuale, presso il ministero o l'agenzia a cui e' provvisoriamente assegnato. Dopo l'approvazione del contratto collettivo e contemporaneamente alla stipula del successivo contratto individuale direttamente con una agenzia fiscale, si provvede all'inquadramento nel ruolo della stessa agenzia. Ai dirigenti transitoriamente distaccati presso un'agenzia fiscale si applicano, nel caso di mancata stipulazione di un contratto individuale, le disposizioni dell'articolo 19, comma 10 del decreto legislativo 3 febbraio 1993, n. 29 e successive integrazioni e modificazioni.

4. Il regolamento emanato ai sensi dell'articolo 58, comma 3, del presente decreto legislativo disciplina, in conformita' con le disposizioni del decreto legislativo 3 febbraio 1993, n.29 e successive integrazioni e modificazioni, l'inquadramento definitivo dei dirigenti provvisoriamente distaccati presso il ministero a termini del comma 3 del presente articolo, e puo', a parita' di oneri a carico del bilancio dello Stato, trasformare le posizioni economiche regolate dalle disposizioni di leggi vigenti per il ministero delle finanze in rapporti di lavoro o di consulenza conformi alle funzioni attribuite dal presente decreto legislativo al ministero.

5. L'inquadramento definitivo del restante personale nelle dotazioni organiche del ministero e delle agenzie fiscali e' disciplinato dal regolamento di cui all'articolo 58, comma 3 e dai regolamenti di cui all'articolo 71, comma 2 del presente decreto legislativo, ferma in ogni caso l'applicazione delle disposizioni previste dalla legislazione vigente e dai contratti collettivi a garanzia del personale dipendente dai ministeri.

---------------- AGGIORNAMENTO (13) Il D.Lgs. 3 luglio 2003, n. 173 ha disposto (con l'art. 1, comma 1, lettera o)) che al comma 4 del presente articolo, le parole: "dell'articolo 58, comma 3, del presente decreto legislativo disciplina, in conformita' con le disposizioni del decreto legislativo 3 febbraio 1993, n. 29, e successive integrazioni e modificazioni" sono sostituite dalle seguenti: "dell'articolo 4 disciplina".

## DISPOSIZIONI IN MATERIA DI ISTRUZIONE NON UNIVERSITARIA, DI UNIVERSITA' E RICERCA, DI POLITICHE AGRICOLE

### Art. 75. - (Disposizioni particolari per l'area dell'istruzione non universitaria)

1. ((COMMA ABROGATO DAL D.L. 9 GENNAIO 2020, N. 1)).

2. ((COMMA ABROGATO DAL D.L. 9 GENNAIO 2020, N. 1)).

3. Relativamente alle competenze in materia di istruzione non universitaria, il ministero ha organizzazione periferica, articolata in uffici scolastici regionali di livello dirigenziale o dirigenziale generale, in relazione alla popolazione studentesca della relativa regione, quali autonomi centri di responsabilita' amministrativa, che esercitano tra le funzioni residuate allo Stato in particolare quelle inerenti all'attivita' di supporto alle istituzioni scolastiche autonome, ai rapporti con le amministrazioni regionali e con gli enti locali, ai rapporti con le universita' e le agenzie formative, al reclutamento e alla mobilita' del personale scolastico, ferma restando la dimensione provinciale dei ruoli del personale docente, amministrativo, tecnico e ausiliare, alla assegnazione delle risorse finanziarie e di personale alle istituzioni scolastiche. Ai fini di un coordinato esercizio delle funzioni pubbliche in materia di istruzione e' costituito presso ogni ufficio scolastico regionale un organo collegiale a composizione mista, con rappresentanti dello Stato, della regione e delle autonomie territoriali interessate, cui compete il coordinamento delle attivita' gestionali di tutti i soggetti interessati e la valutazione della realizzazione degli obiettivi programmati. Alla organizzazione degli uffici scolastici regionali e del relativo organo collegiale si provvede con regolamento adottato ai sensi dell'articolo 17, comma 4 bis, della legge 23 agosto 1988, n. 400. A decorrere dalla entrata in vigore del regolamento stesso, sono soppresse le sovrintendenze scolastiche regionali e, in relazione all'articolazione sul territorio provinciale, anche per funzioni di servizi di consulenza e supporto alle istituzioni scolastiche, sono contestualmente soppressi i provveditorati agli studi.

4. In relazione all'entrata in vigore delle disposizioni di attuazione dell'articolo 21 della legge 15 marzo 1997, n. 59, il riordino dell'area dell'istruzione non universitaria e' definitivamente attuato entro l'anno 2000, garantendo l'invarianza della spesa per le dotazioni organiche di personale previste dal decreto del presidente del consiglio dei ministri del 30 luglio 1996.

5. Fino all'entrata in vigore del regolamento di cui all'articolo 4 il ministro della pubblica istruzione e' autorizzato a sperimentare anche con singoli atti modelli organizzativi conformi alle disposizioni del presente decreto legislativo che consentano l'aggregazione di compiti e funzioni omogenee con attribuzione delle connesse responsabilita' amministrative e contabili al dirigente preposto. Per tali finalita' e' altresi autorizzato a promuovere i procedimenti di formazione, riconversione e riqualificazione necessari in relazione alla nuova organizzazione e alle competenze dell'amministrazione.

### Art. 76.

((ARTICOLO ABROGATO DAL D.L. 9 GENNAIO 2020, N. 1))

### Art. 77.

((ARTICOLO ABROGATO DAL D.L. 9 GENNAIO 2020, N. 1))

### Art. 78. - (Disposizioni per le politiche agricole)

1. Fino alla data di entrata in vigore dei regolamenti di organizzazione del nuovo ministero delle politiche agricole e forestali, il ministero per le politiche agricole e' riordinato ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, art. 400, prevedendo che il dipartimento delle politiche di mercato e il dipartimento della qualita' dei prodotti agroalimentari e dei servizi, sono articolati rispettivamente in due ed in tre uffici di livello dirigenziale generale.

## AGENZIA DI PROTEZIONE CIVILE ((CAPO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 79.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 80.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 81.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 82.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 83.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 84.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 85.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 86.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

### Art. 87.

((ARTICOLO SOPPRESSO DAL D.L. 7 SETTEMBRE 2001, N. 343, CONVERTITO CON MODIFICAZIONI DALLA L. 9 NOVEMBRE 2001, N. 401))

## AGENZIA PER LA FORMAZIONE E L'ISTRUZIONE PROFESSIONALE

### Art. 88.

((ARTICOLO ABROGATO DAL D.L. 9 GENNAIO 2020, N. 1))

### Art. 89. - (Disposizioni finali)

1. Il ministro del tesoro, del bilancio e della programmazione economica e' autorizzato ad apportare, al bilancio dello Stato le variazioni conseguenziali all'applicazione del presente decreto legislativo.

